//// The raw data is pums.csv, which can be downloaded from 
//// https://www.census.gov/data/datasets/2007/econ/sbo/2007-sbo-pums.html

insheet using "pums.csv", comma 
save "pums.dta", replace
*run "NAICS.do"

gen nonemploy=(employment==0)

gen censuscateg=0 if employment==0
replace censuscateg=1 if employment>=1 & employment<=4
replace censuscateg=2 if employment>=5 & employment<=9
replace censuscateg=3 if employment>=10 & employment<=19
replace censuscateg=4 if employment>=20 & employment<=49
replace censuscateg=5 if employment>=50 & employment<=99

gen l=0 if hours1==1
replace l=10 if hours1==2
replace l=30 if hours1==3
replace l=40 if hours1==4
replace l=50 if hours1==5
replace l=65 if hours1==6


gen agef=2007-1975 if estab=="1" // age 28+
replace agef=2007-1985 if estab=="2" // age 18-27
replace agef=2007-1995 if estab=="3" // age 9-17
replace agef=2007-2001 if estab=="4" // age 6-8
replace agef=2007-2003 if estab=="5" // age 5
replace agef=2007-2004 if estab=="6" // age 4
replace agef=2007-2005 if estab=="7" // age 3
replace agef=2007-2006 if estab=="8" // age 2
replace agef=2007-2007 if estab=="9" // age 1

keep if numowners==1
drop if age1==6
drop if hours1==1
keep if prminc1!=2

gen empcateg=0 if employm<1
gen upperlast=0
gen midofcateg=0
gen ncateg=0

forvalues j=1/11 {
replace empcateg=`j' if employm>upperlast & employm<=upperlast+3^(`j'-1)
replace midofcateg=(upperlast+3^(`j'-1)+upperlast+1)/2 if employm>upperlast & employm<=upperlast+3^(`j'-1)
replace ncateg=3^(`j'-1) if employm>upperlast & employm<=upperlast+3^(`j'-1)
replace upperlast=upperlast+3^(`j'-1)
}

gen labor=employment*35 //*52

gen loL=l/labor
gen Lol=labor/l
gen noemp=0 if employment_!=.
replace noemp=1 if employment_==0

gen laboremp=labor if noemp==0

gen logl=log(l)
gen loglabor=log(labor)
gen logy=log(receipts)

gen y=receipts if receipts>0

*agef=0 is age 1, agef=4 is age 6-8

sum agef [aw=tabwgt] if employment<=100
gen meanagef=r(mean)

sum noemp [aw=tabwgt] if employment<=100 
gen meannoemp=r(mean)

sum l if employment>=5 & employment<=100  [aw=tabwgt]
gen meanl5to100=r(mean)

sum l if noemp==1  [aw=tabwgt]
gen meanlnoemp=r(mean)

sum l [aw=tabwgt]
gen meanl=r(mean)

gen nothing=1

sum l [aw=tabwgt] if  employment<=100, d
gen lallp7525=r(p75)/r(p25)

sum y [aw=tabwgt] if employment==0, d
gen yrelmeannoemp=y/r(mean)
gen yrelmediannoemp=y/r(p50)


tab agef [aw=tabwgt] if employment<=100, matcell(x)
matrix list x
svmat x
gen numberage5o1=x1[5]/x1[1]
drop x1


preserve
collapse (mean) meanl lallp7525 meannoemp meanlnoemp meanagef meanl5to100 numberage5o1 yrelmeannoemp y l Lol labor loL (sd) sdlogy=logy sdlogl=logl sdloglabor=loglabor sdLol=Lol (p25) p25y=y p25l=l p25labor=labor ///
 (p50) p50y=y p50l=l p50labor=labor yrelmediannoemp  (p75) p75y=y p75l=l p75labor=labor  (p90) p90y=y p90l=l p90labor=labor  (p95) p95y=y p95l=l p95labor=labor  [aw=tabwgt] if employment>0 & employment<=100, by(nothing)

 
 
foreach x of varlist y l labor {
gen p9590`x'=p95`x'/p90`x'
gen p9075`x'=p90`x'/p75`x'
gen p9050`x'=p90`x'/p50`x'
gen p7525`x'=p75`x'/p25`x'
*gen p9010`x'=p90`x'/p10`x'
} 
 
/* Produce 3 numbers from the SBO mentioned in the Introduction: 
average hours of entrepreneurs, average ratio of own hours to hired hours for employers, and interquartile ratio of own hours*/
export excel meanl loL lallp7525  ///
using "Data moments", sheetreplace firstrow(variables) sheet("In text, intro (SBO)") 

/*Produce 3 numbers mentioned in the text of Section 4:
average output of employers relative to average of non-employers, and the same for medians.*/
export excel yrelmeannoemp yrelmediannoemp  ///
using "Data moments", sheetreplace firstrow(variables) sheet("In text, Section 4 (SBO)") 

/*Produce the targeted statistics from the SBO mentioned  in  Table 1.*/    
export excel meanagef p95labor labor meannoemp l meanl5to100 meanlnoemp numberage5o1 ///
using "Data moments", sheetreplace firstrow(variables) sheet("Table 1 (SBO)") 
 
/*Produce the variation moments of hired labor and output reported in Table 2.*/ 
export excel  p9590labor p9075labor p9050labor  p7525y p9050y p9075y ///
using "Data moments", sheetreplace firstrow(variables) sheet("Table 2 (SBO)")
restore
 
/* Figure 3 (a) */
preserve
collapse (mean) noemp laboremp  [aw=tabwgt] if employment<=100, by(agef)

egen agegp=group(agef) 
 
replace noemp=noemp*100

twoway (line noemp agegp, sort lpattern(solid) lcolor(blue)) (line laboremp agegp, sort lpattern(dash) lcolor(red) yaxis(2)) if agegp<9, ///
ytitle("Fraction of non-employers (%)", size(large)) ytitle("Average labor of employers", size(large) axis(2))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6-8" 7 "9-17" 8 "18-27") ///
legend(order(1 "Frac. non-employers" 2 "Avg. labor, employers") rows(1) region(lcolor(white)))  
graph export "laborage_SBO.pdf", as(pdf) replace
graph export "laborage_SBO.tif", as(tif) replace
  
restore

gen whichage=0

foreach x in l {
gen rhoy`x'_size=.
forvalues i=0/5 {
corr logy log`x' [aw=tabwgt] if censuscateg==`i'
replace rhoy`x'_size=r(rho) if censuscateg==`i'
}
}


/* Figure 2 (a) and (b) */
preserve
collapse (mean) l loL Lol labor rhoyl_size noemp employment (p25) l25=l (p75) l75=l (median) lmed=l loLmed=loL [aw=tabwgt] if employment<100, by(censuscateg)

twoway (line l censuscateg, sort lpattern(solid) lcolor(blue)) (line loL censuscateg, sort lpattern(dash) lcolor(red) yaxis(2)), ///
ytitle("Owner hours", size(large)) ytitle("Owner hours / Hired labor", size(large) axis(2))  ylabel(,nogrid) xtitle("Size category", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(0 "0" 1 "1-4" 2 "5-9" 3 "10-19" 4 "20-49" 5 "50-99") ///
legend(order(1 "Owner hours" 2 "Owner hours / Hired labor") rows(1) region(lcolor(white)))  
graph export "l_size_SBO.pdf", as(pdf) replace
graph export "l_size_SBO.tif", as(tif) replace
  

twoway (line rhoyl_size censuscateg, sort lpattern(solid) lcolor(white)) ///
(line rhoyl_size censuscateg, sort lpattern(solid) lcolor(blue)), ///
ytitle("Corr. sales with owner hours (logs)", size(large)) ylabel(,nogrid) xtitle("Size category", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(0 "0" 1 "1-4" 2 "5-9" 3 "10-19" 4 "20-49" 5 "50-99") ///
legend(order(3 "Median") rows(1) color(white) region(lcolor(white)))  
graph export "rhoyl_size_SBO.pdf", as(pdf) replace
graph export "rhoyl_size_SBO.tif", as(tif) replace

restore
