clear all
*cd "D:\SIPP\Extracts"
local PATH "F:\Data\SIPP\Extracts"
*local PATH "C:\Users\Ariel\Desktop\SIPP\Extracts"

cd "`PATH'"


/***********************************************************
Core data files (are now long, not wide)
**********************************************************/


use sipp96t1, clear
*rename ssuid su_id
sort ssuid eentaid epppnum
keep ssuid eentaid epppnum tmakmnyr eyrsince eyrsinc2
save "sipp96t1_edit.dta", replace

use sipp96l1, clear
sort ssuid eentaid epppnum
merge ssuid eentaid epppnum using "F:\Data\SIPP\Extracts\sipp96t1_edit.dta"

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot
 
**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*rename enrold att_sch
*rename ws12002 jobid1
*rename ws22102 jobid2
*rename ws1occ ws1_oc
*rename ws2occ ws2_oc
*rename ws1ind ws1_in
*rename ws2ind ws2_in
*rename ws1amt ws1_am
*rename ws2amt ws2_am
*rename ws12025 ws1_hr
*rename ws22125 ws2_hr
*rename ws12028 ws1_ra
*rename ws22128 ws2_ra
*rename ws12012 ws1_cl
*rename ws22112 ws2_cl
*rename ws1wks ws1_wk
*rename ws2wks ws2_wk

*Commented out
*rename ws12016 ws1_2016 
*rename ws22116 ws2_2016 
*rename ws12018 ws1_2018 
*rename ws22118 ws2_2018 
*rename ws12020 ws1_2020 
*rename ws22120 ws2_2020 
*rename ws12022 ws1_2022 
*rename ws22122 ws2_2022 
*rename ws12026 ws1_2026
*rename ws22126 ws2_2026

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt
**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

*rename iws12026 ws1imp04
*rename iws12028 ws1imp05
*rename iws22126 ws2imp04
*rename iws22128 ws2imp05

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov
 
#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tmakmnyr eyrsince eyrsinc2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2
socsr1 socsr2 u_comp)
;
#delimit cr

replace tmakmnyr=0 if tmakmnyr==.
replace eyrsince=0 if eyrsince==.
replace eyrsinc2=0 if eyrsinc2==.

*make years not worked to worked
replace eyrsinc2 = h_year-tmakmnyr-eyrsinc2 if eyrsinc2>0

foreach var in tsjdate1 tsjdate2 {
gen aux_`var'=`var'
tostring aux_`var', replace
gen aux2_`var'=substr(aux_`var',5,2)
destring aux2_`var', replace
rename aux2_`var' month_`var'
gen aux2_`var'=substr(aux_`var', 1,4)
destring aux2_`var', replace
rename aux2_`var' year_`var'
cap drop aux*
}

replace month_tsjdate1 = 0 if month_tsjdate1 ==.
replace month_tsjdate2 = 0 if month_tsjdate2 ==.
replace year_tsjdate1 = 0 if year_tsjdate1 ==.
replace year_tsjdate2 = 0 if year_tsjdate2 ==.

foreach var in tsbdate1 tsbdate2 {
gen aux_`var'=`var'
tostring aux_`var', replace
gen aux2_`var'=substr(aux_`var',5,2)
destring aux2_`var', replace
rename aux2_`var' month_`var'
gen aux2_`var'=substr(aux_`var', 1,4)
destring aux2_`var', replace
rename aux2_`var' year_`var'
cap drop aux*
}
drop tsbdate1 tsbdate2 tebdate1 tebdate2

replace month_tsbdate1 = -99 if month_tsbdate1 ==.
replace month_tsbdate2 = -99 if month_tsbdate2 ==.
replace year_tsbdate1 = -99 if year_tsbdate1 ==.
replace year_tsbdate2 = -99 if year_tsbdate2 ==.
replace month_tsbdate1 = -99 if month_tsbdate1 <=0
replace month_tsbdate2 = -99 if month_tsbdate2 <=0
replace year_tsbdate1 = -99 if year_tsbdate1 <=0
replace year_tsbdate2 = -99 if year_tsbdate2 <=0


*generate amount of tenure months
gen aux = h_month-month_tsjdate1 if month_tsjdate1>0
replace aux =1 if aux==-11
replace aux =2 if aux==-10
replace aux =3 if aux==-9
replace aux =4 if aux==-8
replace aux =5 if aux==-7
replace aux =6 if aux==-6
replace aux =7 if aux==-5
replace aux =8 if aux==-4
replace aux =9 if aux==-3
replace aux =10 if aux==-2
replace aux =11 if aux==-1
replace month_tsjdate1=aux if aux>0 & aux!=.
drop aux
gen aux = h_month-month_tsjdate2 if month_tsjdate2>0
replace aux =1 if aux==-11
replace aux =2 if aux==-10
replace aux =3 if aux==-9
replace aux =4 if aux==-8
replace aux =5 if aux==-7
replace aux =6 if aux==-6
replace aux =7 if aux==-5
replace aux =8 if aux==-4
replace aux =9 if aux==-3
replace aux =10 if aux==-2
replace aux =11 if aux==-1
replace month_tsjdate2=aux if aux>0 & aux!=.
drop aux


*tenure cannot be larger than experience
gen exp_aux = tmakmnyr
replace exp_aux = h_year if exp_aux<=0
gen aux = max(year_tsjdate1,exp_aux) if year_tsjdate1>0
replace aux = 0 if aux==.
replace year_tsjdate1 = aux
drop aux exp_aux
gen exp_aux = tmakmnyr
replace exp_aux = h_year if exp_aux<=0
gen aux = max(year_tsjdate2,exp_aux) if year_tsjdate2>0
replace aux = 0 if aux==.
replace year_tsjdate2 = aux
drop aux exp_aux

sort id pp_wave


save 96_1, replace
clear




use sipp96l2, clear
rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr


gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99

drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99

sort id pp_wave



save 96_2, replace
clear



*read in asset data
use sipp96t3, clear

rename thhtwlth hhtwlth
rename thhscdbt hhscdbt                          
rename rhhuscbt hhusdbt                     
rename thhdebt hhdebt
rename thhtnw hhtnw 
rename tvbva1 hhbusval1
rename tvbde1 hhbusdbt1
rename tvbva2 hhbusval2
rename tvbde2 hhbusdbt2
rename talrb ira
rename talkb keogh

#delimit ;
keep (ssuid eentaid epppnum hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr
sort ssuid eentaid epppnum

save "F:\Data\SIPP\Extracts\96_t3", replace

use sipp96l3, clear
sort ssuid eentaid epppnum
merge ssuid eentaid epppnum using "F:\Data\SIPP\Extracts\96_t3.dta"
drop if _merge==2
drop _merge

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2
hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99

drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99

sort id pp_wave

save 96_3, replace
clear



use sipp96l4, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026  tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99

drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99

sort id pp_wave


save 96_4, replace
clear



use sipp96l5, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave



save 96_5, replace
clear


*read asset data
use sipp96t6, clear

rename thhtwlth hhtwlth
rename thhscdbt hhscdbt                          
rename rhhuscbt hhusdbt                     
rename thhdebt hhdebt
rename thhtnw hhtnw 
rename tvbva1 hhbusval1
rename tvbde1 hhbusdbt1
rename tvbva2 hhbusval2
rename tvbde2 hhbusdbt2
rename talrb ira
rename talkb keogh

#delimit ;
keep (ssuid eentaid epppnum hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr
sort ssuid eentaid epppnum

save "F:\Data\SIPP\Extracts\96_t6", replace

use sipp96l6, clear
sort ssuid eentaid epppnum
merge ssuid eentaid epppnum using "F:\Data\SIPP\Extracts\96_t6.dta"

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2
hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave


save 96_6, replace
clear




use sipp96l7, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave


save 96_7, replace
clear




use sipp96l8, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave



save 96_8, replace
clear




*read asset data
use sipp96t9, clear

rename thhtwlth hhtwlth
rename thhscdbt hhscdbt                          
rename rhhuscbt hhusdbt                     
rename thhdebt hhdebt
rename thhtnw hhtnw 
rename tvbva1 hhbusval1
rename tvbde1 hhbusdbt1
rename tvbva2 hhbusval2
rename tvbde2 hhbusdbt2
rename talrb ira
rename talkb keogh

#delimit ;
keep (ssuid eentaid epppnum hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr
sort ssuid eentaid epppnum

save "F:\Data\SIPP\Extracts\96_t9", replace

use sipp96l9, clear
sort ssuid eentaid epppnum
merge ssuid eentaid epppnum using "F:\Data\SIPP\Extracts\96_t9.dta"

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2
hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave



save 96_9, replace
clear


use sipp96l10, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave



save 96_10, replace
clear



use sipp96l11, clear

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave



save 96_11, replace
clear




*read asset data
use sipp96t12, clear

rename thhtwlth hhtwlth
rename thhscdbt hhscdbt                          
rename rhhuscbt hhusdbt                     
rename thhdebt hhdebt
rename thhtnw hhtnw 
rename tvbva1 hhbusval1
rename tvbde1 hhbusdbt1
rename tvbva2 hhbusval2
rename tvbde2 hhbusdbt2
rename talrb ira
rename talkb keogh

#delimit ;
keep (ssuid eentaid epppnum hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr
sort ssuid eentaid epppnum

save "F:\Data\SIPP\Extracts\96_t12", replace

use sipp96l12, clear
sort ssuid eentaid epppnum
merge ssuid eentaid epppnum using "F:\Data\SIPP\Extracts\96_t12.dta"

rename ssuid su_id
rename ssuseq suseqnum
rename eentaid pp_entry
rename epppnum pp_pnum
rename srotaton su_rot

**To use homogeneous suseqnum**
destring suseqnum, replace
destring su_id, replace
format su_id %11.0f


egen id = group(su_id pp_entry pp_pnum)

*Variables already with that name
*rename job start and end
*rename ws1_2018 tsjdate1
*rename ws1_2022 tejdate1
*rename ws2_2018 tsjdate2
*rename ws2_2022 tejdate2

*rename weeks wksper

gen u_comp = t05amt+t07amt

**New variables, if earnings from job are calculated or imputed**
**Imputed earnings and hourly rate
rename apmsum1 ws1calc
rename apmsum2 ws2calc
rename apyrate1 ws1imp05
rename apyrate2 ws2imp05

**Was respondent paid by the hour?
rename epayhr1 ws1_2026
rename epayhr2 ws2_2026

**Part time work. Reason
rename eptresn reason_part
rename aptresn imp_reason_part


rename shhadid h_addid
rename rhcalmn h_month
rename rhcalyr h_year
rename tfipsst state
rename ehrefper h_refper
rename ehhnumpp h_np
rename whfnwgt h_wgt
rename tmetro h_metro
rename thpov h_povd

rename thtotinc h_totinc
rename thearn h_earn 
rename thprpinc h_prop
rename thtrninc h_tran
rename thothinc h_other
rename thnoncsh h_noncsh
rename thsocsec h_socsec
rename thssi h_ssi
rename thunemp h_unemp
rename thvets h_vets
rename thafdc h_afdc
rename thfdstp h_fdstp


rename tptotinc pp_totin 
rename tpearn pp_earn
rename tpprpinc pp_prop
rename tptrninc pp_tran
rename tpothinc pp_other
rename swave pp_wave



gen disab = 0
replace disab = 1 if edisabl==1
rename tage age
rename errp rrp
rename eeno1 jobid1
rename eeno2 jobid2
rename tjbocc1 ws1_oc
rename tjbocc2 ws2_oc

rename ejbind1 ws1_in
rename ejbind2 ws2_in
rename ejbhrs1 ws1_hr
rename ejbhrs2 ws2_hr
rename tpyrate1 ws1_ra
rename tpyrate2 ws2_ra
rename renroll att_sch
rename rwksperm wksper
gen ethnicty=erace
rename eppintvw pp_mis
*Number of weeks employed in the month is general, does not specify the job. Consider both jobs to be the same amount of months worked in the month*
gen ws1_wk=rmwkwjb
gen ws2_wk=rmwkwjb 
replace ws2_wk=-9 if jobid1==-9
replace ws1_wk=-9 if jobid2==-9
*join part time and full time school
gen school =0 if att_sch==-1
replace school =1 if att_sch==1
replace school =2 if att_sch==2
replace school =3 if att_sch==3
rename wpfinwgt p_wgt_

rename esex sex
rename eeducate higrade
rename ems ms
rename erace race
gen esr=rmesr 
*Self employed variable not there, take as a proxy if the person owns a business*
gen sc1714=0
replace sc1714=1 if rmesr>0
replace sc1714=2 if ebuscntr>0
gen ws1_cl=eclwrk1
gen ws2_cl=eclwrk2
gen ws1_am=tpmsum1 
gen ws2_am=tpmsum2 
gen in_af=eafnow

rename ebno1 se1_id
rename ebno2 se2_id
rename tbmsum1 se1_am
rename tbmsum2 se2_am
rename tbsind1 se1_ind
rename tbsind2 se2_ind
rename tbsocc1 se1_occ
rename tbsocc2 se2_occ
rename ehrsbs1 se1_hr
rename ehrsbs2 se2_hr
rename tprftb1 se12256
rename tprftb2 se22256
rename tempb1 se12218
rename tempb2 se22218
rename eincpb1 se12220
rename eincpb2 se22220
rename aincpb1 ise12220
rename aincpb2 ise22220
rename aempb1 ise12218
rename aempb2 ise22218
rename abmsum1 se1cal
rename abmsum2 se2cal
rename eresnss1 socsr1
rename eresnss2 socsr2
rename ecdmth caidcov

#delimit ;
keep (id suseqnum su_id su_rot h_month h_year age h_addid h_refper h_np h_wgt p_wgt_ h_povd state etenure rfoklt18
h_metro h_povd h_totinc h_earn h_prop h_tran h_other h_noncsh h_socsec h_ssi h_unemp h_vets 
h_afdc h_fdstp pp_totin pp_earn pp_prop pp_tran pp_other rrp rmhrswk caidcov
tsjdate1 tsjdate2 tejdate1 tejdate2 ebiznow1 ebiznow2
pp_wave pp_entry pp_pnum disab age rrp jobid* ws1_oc ws2_oc ws1_in ws2_in ws1_hr ws2_hr ws1_wk ws2_wk
ws1_ra ws2_ra att_sch wksper ethnicty pp_mis ws1_wk ws2_wk school sex school higrade ms race esr sc1714 ws1_cl ws2_cl ws1_am ws2_am in_af ws1calc ws2calc ws1imp05 ws2imp05 ws1_2026 ws2_2026 tsjdate1 tejdate1 tsjdate2 tejdate2 reason_part imp_reason_part
se1_id se2_id se1_am se2_am se1_ind se2_ind se1_occ se2_occ se1_hr se2_hr se12256 se22256 se12218 se22218 se12220 se22220 ise12220 ise22220 ise12218 ise22218
socsr1 socsr2 u_comp
tsbdate1 tsbdate2 tebdate1 tebdate2 se1cal se2cal tempsiz1 tempall1 tempsiz2 tempall2
hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 ira keogh)
;
#delimit cr

gen month_tsjdate1=-99
gen month_tsjdate2=-99
gen year_tsjdate1=-99
gen year_tsjdate2=-99
gen tmakmnyr =-99
gen eyrsince =-99
gen eyrsinc2 =-99


drop tsbdate1 tsbdate2 tebdate1 tebdate2

gen month_tsbdate1=-99
gen month_tsbdate2=-99
gen year_tsbdate1=-99
gen year_tsbdate2=-99


sort id pp_wave

save 96_12, replace
clear
 

/***********************************************************
*merge monthly data (should be no matches)
**********************************************************/
use "96_1.dta", clear
merge id pp_wave using "96_2.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_3.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_4.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_5.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_6.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_7.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_8.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_9.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_10.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_11.dta"
tab _merge
drop _merge
sort id pp_wave
merge id pp_wave using "96_12.dta"
tab _merge
drop _merge

*drop if pp_mis !=1
*drop pp_mis
drop id


rename month_tsjdate1 month_tenure1
rename year_tsjdate1 year_tenure1
rename month_tsjdate2 month_tenure2
rename year_tsjdate2 year_tenure2
rename tmakmnyr first_exp
rename eyrsince all_work
rename eyrsinc2 years_exp
rename etenure h_tenur 
rename rfoklt18 f_oklt18
rename h_addid h_add 



*extrapolate business value
replace hhtnw = hhtnw-hhbusval1-hhbusval2-ira-keogh

gen  hhbusval1_tc = 0
replace  hhbusval1_tc = 1 if hhbusval1>=3700000 & hhbusval1~=.
local T=3700000
qui sum hhbusval1_tc if hhbusval1~=.
local F2=r(mean)
_pctile hhbusval1 if hhbusval1!=. & se1_id>0, p(95)
local y8=r(r1)
local alpha8=ln((1-0.95)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if hhbusval1_tc==1
replace hhbusval1=check if hhbusval1_tc==1
cap drop check hhbusval1_tc

gen  hhbusval2_tc = 0
replace  hhbusval2_tc = 1 if hhbusval2>=3700000 & hhbusval2~=.
local T=3700000
qui sum hhbusval2_tc if hhbusval2~=.
local F2=r(mean)
_pctile hhbusval2 if hhbusval2!=. & se2_id>0, p(95)
local y8=r(r1)
local alpha8=ln((1-0.95)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if hhbusval2_tc==1
replace hhbusval2=check if hhbusval2_tc==1
cap drop check hhbusval2_tc

replace hhtnw = hhtnw+hhbusval1+hhbusval2


egen id = group(su_id pp_entry pp_pnum)

replace u_comp=0 if u_comp==.

drop imp_reason_part
cap drop school
rename att_sch school


*define disability insurance
gen index = socsr1==2 | socsr2==2
sort id h_year h_month
by id: egen di= sum(index)
replace di=0 if h_socsec==0
replace di = di>0
drop socsr1 socsr2 index


****************generate business experience****************************
*generate experience accumulated in panel: Worker gets an extra year of experience each callender year that he has the business
sort id h_year h_month
egen id_year = group(id h_year)
sort id_year
gen index = 0
replace index=1 if se1_id>0
by id_year: egen extra_exp_aux1 = sum(index)
drop index
replace extra_exp_aux1=1 if extra_exp_aux1>0
by id_year: gen index = id_year[_n+1]
replace extra_exp_aux1=0 if index!=.
sort id h_year h_month
by id: gen index2 = extra_exp_aux1[_n-1]
replace index2=0 if index2==.
by id: gen extra_exp_b1 = sum(index2)
drop index index2
gen index = 0
replace index=1 if se2_id>0
sort id_year
by id_year: egen extra_exp_aux2 = sum(index)
drop index
replace extra_exp_aux2=1 if extra_exp_aux2>0
by id_year: gen index = id_year[_n+1]
replace extra_exp_aux2=0 if index!=.
sort id h_year h_month
by id: gen index2 = extra_exp_aux2[_n-1]
replace index2=0 if index2==.
by id: gen extra_exp_b2 = sum(index2)
drop index index2 
*potential experience
sort id
by id: egen index = min(h_year)
replace index=index==h_year
gen pot_exp1_aux = 0
replace pot_exp1_aux = h_year-year_tsbdate1 if index==1
replace pot_exp1_aux = 0 if year_tsbdate1==-99
by id: egen pot_exp1 = max(pot_exp1_aux)
gen pot_exp2_aux = 0
replace pot_exp2_aux = h_year-year_tsbdate2 if index==1
replace pot_exp2_aux = 0 if year_tsbdate2==-99
by id: egen pot_exp2 = max(pot_exp2_aux)
drop index pot_exp1_aux pot_exp2_aux
*generate actual experience 
gen exper_b1 = pot_exp1+extra_exp_b1
gen exper_b2 = pot_exp2+extra_exp_b2
drop pot_exp2 pot_exp1 extra_exp_b2 extra_exp_aux2 extra_exp_b1 extra_exp_aux1 id_year year_tsbdate2 month_tsbdate2 year_tsbdate1 month_tsbdate1


replace ws1_hr = 40 if ws2_hr <=0 & ws1_hr==-8 & (rmhrswk==1 | rmhrswk==5)
replace ws2_hr = 40 if ws1_hr <=0 & ws2_hr==-8 & (rmhrswk==1 | rmhrswk==5)
drop rmhrswk

*join private profit, not profit, and family worker
replace ws1_cl =0 if ws1_cl==-1
replace ws1_cl =1 if ws1_cl==2
replace ws1_cl =2 if ws1_cl==3
replace ws1_cl =3 if ws1_cl==4
replace ws1_cl =4 if ws1_cl==5
replace ws1_cl =2 if ws1_cl==6
replace ws2_cl =0 if ws2_cl==-1
replace ws2_cl =1 if ws2_cl==2
replace ws2_cl =2 if ws2_cl==3
replace ws2_cl =3 if ws2_cl==4
replace ws2_cl =4 if ws2_cl==5
replace ws2_cl =2 if ws2_cl==6


label variable ws1_cl   "Worker class"
label define ws1_class 0 "Not in Universe" 1 "A private company or individual" 2 "Federal government" 3 "State government" 4 "Local government" 5 "Armed Forces"                  
label values ws1_cl ws1_class	
label variable ws2_cl   "Worker class"
label define ws2_class 0 "Not in Universe" 1 "A private company or individual" 2 "Federal government" 3 "State government" 4 "Local government" 5 "Armed Forces"                  
label values ws2_cl ws2_class

gen panel = 96
sort su_id pp_entry pp_pnum h_year h_month panel

save "96_panel_e.dta", replace
clear
