
set more off


cd "F:\Data\SIPP\Extracts"

cap log close




**************************************************************
**			
**				CREATE REVISED PANELS WITH RELEVANT POPULATION
**
***************************************************************


use 96_panel_e, clear
tostring su_id, replace format("%12.0f")


**DROP PP_MIS DIFFERENT FROM 1 (2001 onwards we drop at Merging Panels1***
**All monthly variables in the users data extract should be set to a missing value for months when PP-MIS is not equal to 1**
drop if pp_mis !=1
drop pp_mis

cap rename higrade grade
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
rename tsjdate1 ws1_2016
rename tejdate1 ws1_2020  
rename tsjdate2 ws2_2016
rename tejdate2 ws2_2020
cap tostring pp_pnum, replace
tostring pp_entry, replace
destring h_add, replace

gen se1_wk = ws1_wk
gen se2_wk = ws2_wk

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=20 & age<=64
******************************************************************************

save 96_panel_e_revised, replace


use 2001_panel_e, clear
tostring su_id, replace format("%12.0f")


drop if pp_mis !=1
drop pp_mis

cap rename higrade grade
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
rename tsjdate1 ws1_2016
rename tejdate1 ws1_2020  
rename tsjdate2 ws2_2016
rename tejdate2 ws2_2020
cap tostring pp_pnum, replace
tostring pp_entry, replace
rename h_addid h_add
destring h_add, replace

gen se1_wk = ws1_wk
gen se2_wk = ws2_wk
**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=20 & age<=64
******************************************************************************

save 2001_panel_e_revised, replace


use 2004_panel_e, clear
tostring su_id, replace format("%12.0f")



drop if pp_mis !=1
drop pp_mis

cap rename state_ state
cap rename higrade grade
cap rename ws1_amt ws1_am
cap rename ws2_amt ws2_am
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap rename h_metro_  h_metro
rename tsjdate1 ws1_2016
rename tejdate1 ws1_2020  
rename tsjdate2 ws2_2016
rename tejdate2 ws2_2020
cap tostring pp_pnum, replace
tostring pp_entry, replace
rename h_addid_ h_add
destring h_add, replace

gen se1_wk = ws1_wk
gen se2_wk = ws2_wk

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=20 & age<=64
******************************************************************************

save 2004_panel_e_revised, replace



use 2008_panel_e, clear
tostring su_id, replace format("%12.0f")


drop if pp_mis !=1
drop pp_mis

cap rename state_ state
cap rename higrade grade
cap rename ws1_amt ws1_am
cap rename ws2_amt ws2_am
cap rename grd_cmp grd_comp
cap rename p_wgt_ fnlwgt_
cap rename h_metro_  h_metro
rename tsjdate1 ws1_2016
rename tejdate1 ws1_2020  
rename tsjdate2 ws2_2016
rename tejdate2 ws2_2020
cap tostring pp_pnum, replace
tostring pp_entry, replace
rename h_addid_ h_add 
destring h_add, replace

gen se1_wk = ws1_wk
gen se2_wk = ws2_wk

**********************************KEEP ONLY AGED 22 TO 61***************
count if h_year!=.
keep if age>=20 & age<=64
******************************************************************************

save 2008_panel_e_revised, replace



******************************************************************************
**	1996 - 2008
******************************************************************************
use 96_panel_e_revised, clear
append using 2001_panel_e_revised
append using 2004_panel_e_revised
append using 2008_panel_e_revised

rename panel panel_year
**PART TIME HOMOGENOUS ACROSS PANELS**


*First, define the new id
cap drop id
egen id = group(su_id pp_entry pp_pnum panel_year)	
tostring id, replace


*****CREATE WEIGHTS*****************************
rename fnlwgt_ wpfinwgt
cap drop fnlwgt*


sort id h_year h_month

*****CREATE SOME DEMOG*****
gen     region=1 if state==9|state==61|state==33|state==34|state==36|state==42|state==44|state==25
replace region=2 if state==17|state==18|state==62|state==20|state==26|state==27|state==29|state==31|state==39|state==55
replace region=3 if state==1|state==13|state==22|state==28|state==45|state==5|state==10|state==12|state==21|state==24|state==37|state==40|state==47|state==51|state==11|state==54
replace region=4 if region==. & state>0 & state<64
gen white  =race==1
gen married=ms==1|ms==2


drop if state==0
drop if wpfinwgt==0


replace esr=8 if jobid1 ==. & jobid2 ==. & se1_id ==. & se2_id ==. & esr<=4 

*drop in armed forces
drop if in_af==1
drop in_af


*clean employment
replace ws1_am = 0 if ws1_am < 50 
replace ws2_am = 0 if ws2_am < 50
replace ws1_hr = 0 if ws1_hr < 5
replace ws2_hr = 0 if ws2_hr < 5
replace jobid1 = 0 if ws1_am==0 | ws1_hr==0
replace jobid2 = 0 if ws2_am==0 | ws2_hr==0
replace ws1_am = 0 if jobid1==0
replace ws2_am = 0 if jobid2==0
replace ws1_hr = 0 if jobid1==0
replace ws2_hr = 0 if jobid2==0
replace ws1_wk = 0 if jobid1==0
replace ws2_wk = 0 if jobid2==0
replace esr = 5 if esr < 5 & esr >0 & ws1_am == 0 & ws2_am == 0 

*clean self-employment
replace se1_hr=0 if se1_hr<5
replace se2_hr=0 if se2_hr<5
replace se1_am=0 if se1_hr<=0
replace se2_am=0 if se2_hr<=0
replace se1_id = 0 if ebiznow1<=0
replace se2_id = 0 if ebiznow2<=0
replace se1_id = 0 if se1_hr<=0
replace se2_id = 0 if se2_hr<=0
replace se1_am = 0 if se1_id==0
replace se2_am = 0 if se2_id==0
replace se1_hr = 0 if se1_id==0
replace se2_hr = 0 if se2_id==0
replace se1_wk = 0 if se1_id==0
replace se2_wk = 0 if se2_id==0

*generate self employed
gen inc_self = se1_am+se2_am
gen inc_work = ws1_am+ws2_am
gen self = 0
replace self = 1 if (se1_id>0 | se2_id>0) & inc_self>inc_work 


*share of self employed by year
gen w_emp = 0
replace w_emp = wpfinwgt if (jobid1>0 | jobid2>0) & self==0
gen w_self = 0
replace w_self = wpfinwgt if self==1
sort h_year
by h_year: egen n_emp = sum(w_emp)
by h_year: egen n_self = sum(w_self)
gen share_self = n_self/(n_emp+n_self)


*extrapolate earnings
forval x=1(1)2 {
gen  earn`x'_tc = ws`x'_am>=12500 if ws`x'_am~=. 
}

forval x=1(1)2 {
gen tc=0 if esr<=4 
replace tc=1 if earn`x'_tc==1
**Cutoff used for earnings**
local T=12500
qui sum tc [aw=wpfinwgt]
local F2=r(mean) /* probability that weekly earnings is above the topcode;
                    analagous to 1-F(y2) above */
* b. calculate alternative values for y1
_pctile ws`x'_am if tc~=. & ws`x'_am!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace ws`x'_am=check if tc==1
**Draw from the distribution above 80% which is Pareto distributed**
**Use only the values which are bove the top-coded**
drop check tc earn`x'_tc
}

forval x=1(1)2 {
gen  self`x'_tc = se`x'_am>=12500 if se`x'_am~=. 
}

forval x=1(1)2 {
gen tc=0 if self==1 
replace tc=1 if self`x'_tc==1
**Cutoff used for earnings**
local T=12500
qui sum tc [aw=wpfinwgt]
local F2=r(mean) /* probability that weekly earnings is above the topcode;
                    analagous to 1-F(y2) above */
* b. calculate alternative values for y1
_pctile se`x'_am if tc~=. & se`x'_am!=0, p(80)
local y8=r(r1)

local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')

gen check=`T'/((1-runiform())^(1/`alpha8')) if tc==1
replace se`x'_am=check if tc==1

drop check tc self`x'_tc
}

*topcoded buseq
rename pp_ear earn
gen  earn_tc = earn>=8333 
local T=8333
qui sum earn_tc
local F2=r(mean)
_pctile earn if earn!=0, p(80)
local y8=r(r1)
local alpha8=ln((1-0.8)/(`F2'))/ln(`T'/`y8')
gen check=`T'/((1-runiform())^(1/`alpha8')) if earn_tc==1
replace earn=check if earn_tc==1
cap drop check earn_tc


*****CPI****************

**Replace year to merge with CPI
rename h_year year
rename h_month month
replace year=year+1900 if year<100

cap drop _merge
sort year month
merge year month using cpi_monthly
tab year if _merge==1
drop if _merge!=3
drop _merge
replace cpi=(cpi/118)*100				


replace ws1_am = ws1_am/(cpi/100)
replace ws2_am = ws2_am/(cpi/100)
replace se1_am = se1_am/(cpi/100)
replace se2_am = se2_am/(cpi/100)

*generate monthly hours
gen se1_hr_m = se1_hr*se1_wk
gen se2_hr_m = se2_hr*se2_wk
gen ws1_hr_m = ws1_hr*ws1_wk
gen ws2_hr_m = ws2_hr*ws2_wk

*unemployment income
replace u_comp = u_comp+pp_tran
replace u_comp = u_comp/(cpi/100)

drop su_rot h_refper h_np h_wgt h_metro h_tenur h_earn h_prop h_tran h_other h_totinc h_povd h_noncsh h_socsec h_ssi h_unemp h_vets h_afdc h_fdstp f_oklt18 rrp earn pp_prop pp_tran pp_other pp_totin
drop school grade reason_part wksper ws1_2016 ws1_2020 ws1calc ws1_2026 ws1_ra ws1imp05 ws2_2016 ws2_2020 ws2calc ws2_2026 ws2_ra ws2imp05 ise12218 ise12220 se1cal ise22218 ise22220 se2cal
drop exper_b1 exper_b2 married inc_self inc_work self w_emp w_self n_emp n_self share_self cpi sc1714
drop se1_hr se2_hr ws1_hr ws2_hr


compress
save data_e3,replace


*******************************************************************************************************************************************************
***************************************************Construct wave dataset*************************************************************************
*******************************************************************************************************************************************************


use data_e3,clear

**do we observe all months of a wave?
egen obs_wave = sum(id!="."), by(id pp_wave)
replace obs_wave = obs_wave==4
drop if obs_wave!=1
drop obs_wave

foreach var in state wpfinwgt age ms jobid1 tempall1 tempsiz1 ws1_in ws1_oc jobid2 tempall2 tempsiz2 ws2_in ws2_oc se1_id se12218 se12220 se1_ind se1_occ se2_id se22218 se22220 se2_ind se2_occ disab esr ws1_cl ws2_cl di region{
bysort id year pp_wave: egen aux = mode(`var'), missing minmode 
replace `var'=aux
drop aux
}

collapse (sum) se1_am se2_am se22256 ws1_am ws2_am se1_hr_m se2_hr_m ws1_hr_m ws2_hr_m u_comp se1_wk se2_wk ws1_wk ws2_wk (median) state wpfinwgt age ms jobid1 tempall1 tempsiz1 ws1_in ws1_oc jobid2 tempall2 tempsiz2 ws2_in ws2_oc se1_id se12218 se12220 se1_ind se1_occ se2_id se22218 se22220 se2_ind se2_occ disab esr ws1_cl ws2_cl di region (first) year suseqnum su_id h_add pp_entry pp_pnum sex race ethnicty panel_year white (max) hhbusval1 hhbusdbt1 hhbusval2 hhbusdbt2 hhtnw hhtwlth hhdebt hhscdbt hhusdbt, by(id pp_wave)


save data2_e3_wave,replace



cap drop id
egen id = group(su_id pp_entry pp_pnum panel_year)


*********aggregate self employment**************
*main self-emploiment job
gen self_main = 0
replace self_main = 1 if se1_am>=se2_am
replace self_main = 2 if se2_am>se1_am

gen self_am = se1_am+se2_am
gen self_hr_m = se1_hr_m+se2_hr_m
gen self_week = se1_wk+se2_wk

gen self_val = hhbusval1+hhbusval2
gen self_dbt = hhbusdbt1+hhbusdbt2
gen self_ind = 0
gen self_n_emp = 0
replace self_n_emp = se12218 if self_main == 1
replace self_n_emp = se22218 if self_main == 2


*************************Agregate employment****************
gen emp_am = ws1_am+ws2_am
gen emp_hr_m = ws1_hr_m+ws2_hr_m
gen emp_week = ws1_wk+ws2_wk

*main employment job
gen emp_main = 0
replace emp_main = 1 if ws1_am>0
replace emp_main = 2 if ws2_am>ws1_am


gen emp_size = 0
replace emp_size = tempsiz1 if emp_main == 1
replace emp_size = tempsiz2 if emp_main == 2

gen emp_cl = 0
replace emp_cl = ws1_cl if emp_main == 1
replace emp_cl = ws2_cl if emp_main == 2


gen self_hourly = self_am/self_hr_m
gen emp_hourly = emp_am/emp_hr_m

*drop out of labor force
replace esr = 7 if esr==8 & (emp_am>0 | self_am>0 | self_hr>0)
drop if esr==8

*regenerate self employment
gen self = 0
replace self=1 if self_am>emp_am
replace self=1 if emp_am<=0 & self_hr_m>0

*create non-employed (second are marginal self employed with less than 100 earnings per wave)
gen emp=1
replace emp = 0 if emp_am<=0 & self_am<=0 & self_hr<=0
replace emp = 0 if emp_am < 100 & self==0


*drop large employers and those not working
drop if self_n_emp==3 & self==1
drop if self_hr_m==0 & self==1


*create new id when observation is missing
egen id2=group(su_id pp_entry pp_pnum panel_year)
drop id
rename id2 id
egen time = group(year pp_wave)
sort id time
by id: gen dtime = time[_n]-time[_n-1]
replace dtime=1 if dtime==.
replace dtime = dtime>1
by id: gen cdtime = sum(dtime)
egen id2 = group(id cdtime)
drop id
rename id2 id
format %16.0g id
recast double id
tostring id, replace


sort id year pp_wave

cd "F:\Entrepenuer\Clean Codes\Moments SIPP"

save data3_e3_wave, replace
