cd "F:\Entrepenuer\Clean Codes\Moments SIPP"


use data3_e3_wave, clear


keep if emp==1

*mean self-employed, hours and earnings (hours and earnings are in wave frequency)
sum self [aweight=wpfinwgt]
gen share_self = r(mean)
sum self_hr_m [aweight=wpfinwgt] if self==1
gen lself_hr_m = log(self_hr_m)
sum lself_hr_m [aweight=wpfinwgt] if self==1
gen lself_hr_m_sd = r(sd)
sum self_am [aweight=wpfinwgt] if self==1, de
gen aux = r(mean)
gen aux2 = r(p50)
egen earn_self_mean = max(aux)
egen earn_self_median = max(aux2)
drop aux aux2
sum emp_am [aweight=wpfinwgt] if self==0, de
gen aux = r(mean)
gen aux2 = r(p50)
egen earn_worker_mean = max(aux)
egen earn_worker_median = max(aux2)
drop aux aux2
gen earn_ratio_median = earn_self_median/earn_worker_median
gen earn_ratio_mean = earn_self_mean/earn_worker_mean
preserve
keep if [_n]==1
cd "C:\Users\fwellsch\Dropbox\WY (1)\Final submission\Replication Package\Moments SIPP"
export excel earn_ratio_median earn_ratio_mean using "Data moments", sheetreplace firstrow(variables) sheet("In text, Section 4 (SIPP)")
restore
drop earn_ratio_median earn_ratio_mean

*income dispersion among workers
preserve
keep if self==0
ineqdeco emp_am
restore

*earnings and hours outside of business (footnote 2)
gen earn_ratio = emp_am/(self_am+emp_am)
gen hr_ratio = emp_hr_m/(self_hr_m+emp_hr_m)
sum  hr_ratio if self==1
gen hr_ratio_mean = r(mean)
sum  earn_ratio if self==1
gen earn_ratio_mean = r(mean)

preserve
keep if [_n]==1
cd "C:\Users\fwellsch\Dropbox\WY (1)\Final submission\Replication Package\Moments SIPP"
export excel hr_ratio_mean earn_ratio_mean using "Data moments", sheetreplace firstrow(variables) sheet("In text, footnote 2 (SIPP)")
restore


*hours dispersion
preserve
keep if self==1
egen top10 = pctile(self_hr_m), p(90)
egen top25 = pctile(self_hr_m), p(75)
egen top75 = pctile(self_hr_m), p(25)
egen top90 = pctile(self_hr_m), p(10)
gen r9010 =top10/top90
sum r9010
gen h_r9010 = r(mean)
gen r9075 =top10/top25
sum r9075
gen h_r9075 = r(mean)
gen r7525 =top25/top75
sum r7525
gen h_r7525 = r(mean)
keep if [_n]==1
cd "C:\Users\fwellsch\Dropbox\WY (1)\Final submission\Replication Package\Moments SIPP"
export excel h_r9010 h_r9075 h_r7525 using "Data moments", sheetreplace firstrow(variables) sheet("Table 2 (SIPP)")
restore


*correlation wealth hours/profits
preserve
keep if self==1
keep if hhtnw!=.
keep if hhtnw>0
keep if self_hr_m>0
gen lhhtnw = log(hhtnw)
gen lself_am = log(self_am)
pwcorr lhhtnw lself_am
restore


*wealth inequality society and wealth to income ratio
preserve
keep if hhtnw!=.
egen total_wealth = sum(hhtnw)
egen total_income_w = sum(emp_am)
egen total_income_e = sum(self_am)
gen wealth_inc = total_wealth/((total_income_w+total_income_e)*3)
sum wealth_inc
gen wealth_inc_ratio = r(mean)
egen top10 = pctile(hhtnw), p(90)
egen top25 = pctile(hhtnw), p(75)
egen top50 = pctile(hhtnw), p(50)
egen top75 = pctile(hhtnw), p(25)
gen ratio90_75 = top10/top25
sum ratio90_75
gen soc_ratio90_75 = r(mean)
gen ratio50_25 = top50/top75
sum ratio50_25
gen soc_ratio50_25 = r(mean)
keep if hhtnw>0
gen lhhtnw = log(hhtnw)
sum lhhtnw
gen soc_lwealth_sd = r(sd)
keep if [_n]==1
cd "C:\Users\fwellsch\Dropbox\WY (1)\Final submission\Replication Package\Moments SIPP"
export excel share_self lself_hr_m_sd wealth_inc_ratio using "Data moments", sheetreplace firstrow(variables) sheet("Calibration (SIPP)")
export excel soc_lwealth_sd soc_ratio90_75 soc_ratio50_25 using "Data moments", sheetreplace firstrow(variables) sheet("In text, society wealth (SIPP)")
restore



*wealth inequality owners
preserve
keep if hhtnw!=.
egen total_wealth_worker = sum(hhtnw) if self==0
egen aux = max(total_wealth_worker) 
replace total_wealth_worker = aux if total_wealth_worker==.
drop aux
egen total_wealth_entre = sum(hhtnw) if self==1
egen aux = max(total_wealth_entre) 
replace total_wealth_entre = aux if total_wealth_entre==.
drop aux
gen wealthratio_entre_worker = total_wealth_entre/total_wealth_worker
sum wealthratio_entre_worker
egen ave_wealth_worker = mean(hhtnw) if self==0
egen aux = max(ave_wealth_worker) 
replace ave_wealth_worker = aux if ave_wealth_worker==.
drop aux
egen med_wealth_worker = median(hhtnw) if self==0
egen aux = max(med_wealth_worker) 
replace med_wealth_worker = aux if med_wealth_worker==.
drop aux
egen med_wealth_entre = median(hhtnw) if self==1
egen aux = max(med_wealth_entre) 
replace med_wealth_entre = aux if med_wealth_entre==.
drop aux
egen ave_wealth_entre = mean(hhtnw) if self==1
egen aux = max(ave_wealth_entre) 
replace ave_wealth_entre = aux if ave_wealth_entre==.
drop aux
gen wealthaveratio_entre_worker = ave_wealth_entre/ave_wealth_worker
sum wealthaveratio_entre_worker
gen wealthaveratio_entre_worker_out = r(mean)
gen wealthmedratio_entre_worker = med_wealth_entre/med_wealth_worker
sum wealthmedratio_entre_worker
egen top5 = pctile(hhtnw), p(95)
egen top10 = pctile(hhtnw), p(90)
egen top25 = pctile(hhtnw), p(75)
egen top50 = pctile(hhtnw), p(50)
egen top75 = pctile(hhtnw), p(25)
keep if self==1
*Fraction of owners falling in parts of the wealth distribution
gen frac_entre_top5 = hhtnw>=top5
sum frac_entre_top5
gen frac_entre_top5_out = r(mean)
gen frac_entre_top10 = hhtnw>=top10
sum frac_entre_top10
gen frac_entre_top10_out = r(mean)
gen frac_entre_top25 = hhtnw>=top25
sum frac_entre_top25
gen frac_entre_top25_out = r(mean)
gen frac_entre_bottom50 = hhtnw<=top50
sum frac_entre_bottom50
gen frac_entre_bottom50_out = r(mean)
gen frac_entre_bottom25 = hhtnw<=top75
sum frac_entre_bottom25
gen frac_entre_bottom25_out = r(mean)
*Owners wealth relative to worker wealth
drop top5 top10 top25 top50 top75
egen top5 = pctile(hhtnw), p(95)
egen top10 = pctile(hhtnw), p(90)
egen top25 = pctile(hhtnw), p(75)
egen top50 = pctile(hhtnw), p(50)
egen top75 = pctile(hhtnw), p(25)
gen entre_rel_worker_wealtht5 = top5/ave_wealth_worker
sum entre_rel_worker_wealtht5
gen entre_rel_worker_wealtht5_out = r(mean)
gen entre_rel_worker_wealtht10 = top10/ave_wealth_worker
sum entre_rel_worker_wealtht10
gen entre_rel_worker_wealtht10_out = r(mean)
gen entre_rel_worker_wealtht25 = top25/ave_wealth_worker
sum entre_rel_worker_wealtht25
gen entre_rel_worker_wealtht25_out = r(mean)
gen entre_rel_worker_wealtht50 = top50/ave_wealth_worker
sum entre_rel_worker_wealtht50
gen entre_rel_worker_wealtht50_out = r(mean)
gen entre_rel_worker_wealtht75 = top75/ave_wealth_worker
sum entre_rel_worker_wealtht75
gen entre_rel_worker_wealtht75_out = r(mean)
*owners wealth dispersion
gen ratio9075 = top10/top25
sum ratio9075
gen ratio9075_out = r(mean)
gen ratio9050 = top10/top50
sum ratio9050
gen ratio9050_out = r(mean)
gen ratio7550 = top75/top50
sum ratio7550
gen ratio7550_out = r(mean)
gen ratio7525 = top25/top75
sum ratio7525
gen ratio7525_out = r(mean)
gen ratio5025 = top50/top75
sum ratio5025
gen ratio5025_out = r(mean)
*std of log wealth
keep if hhtnw>0
gen lhhtnw =log(hhtnw)
sum lhhtnw
gen lhhtnw_sd = r(sd)
keep if [_n]==1
cd "C:\Users\fwellsch\Dropbox\WY (1)\Final submission\Replication Package\Moments SIPP"
export excel frac_entre_top5_out frac_entre_top10_out frac_entre_top25_out frac_entre_bottom50_out frac_entre_bottom25_out using "Data moments", sheetreplace firstrow(variables) sheet("Table 4 (SIPP)")
export excel wealthaveratio_entre_worker_out entre_rel_worker_wealtht5_out entre_rel_worker_wealtht10_out entre_rel_worker_wealtht25_out entre_rel_worker_wealtht50_out entre_rel_worker_wealtht75_out lhhtnw_sd ratio9075_out ratio9050_out ratio7550_out ratio7525_out ratio5025_out using "Data moments", sheetreplace firstrow(variables) sheet("Table 3 (SIPP)")
restore

