
/* This code takes the output of the matlab files used for the solution of the model.
In order to be consistent in the format of figures from the data and the model, we use Stata to convert the matlab output to figures.*/

///// Figure 1 /////

clear
insheet a hours labor using  "policies.csv", comma

twoway (line hours a, sort lpattern(solid) lcolor(blue))  ///
(line labor a, sort lpattern(shortdash) lcolor(green) yaxis(2)) if a<=15, ///
ytitle("Owner hours", size(large)) ytitle("Hired labor", size(large) axis(2))  ylabel(,nogrid) xtitle("Assets (normalized, mean=1)", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
legend(order(1 "Owner hours" 2  "Hired labor") rows(1) region(lcolor(white)))  
graph export "policyzhighvlow.pdf", as(pdf) replace
graph export "policyzhighvlow.tif", as(tif) replace
  
///// Figure 2 Model ////////
clear
insheet hours hol rhohy using  "aux_f2.csv", comma nonames
destring, force replace

gen sizecateg=_n-1
twoway (line hours sizecateg, sort lpattern(solid) lcolor(blue)) (line hol sizecateg if sizecateg>0, sort lpattern(dash) lcolor(red) yaxis(2)), ///
ytitle("Owner hours", size(large)) ytitle("Owner hours / Hired labor", size(large) axis(2))  ylabel(,nogrid) xtitle("Size category", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(0 "0" 1 "1-4" 2 "5-9" 3 "10-19" 4 "20-49" 5 "50-99") ///
legend(order(1 "Owner hours" 2 "Owner hours / Hired labor") rows(1) region(lcolor(white)))  
graph export "h_size_model.pdf", as(pdf) replace
graph export "h_size_model.tif", as(tif) replace

twoway (line rhohy size, sort lpattern(solid) lcolor(blue)) if sizecateg<6, ///
ytitle("Correlation with owner hours (logs)", size(large)) ylabel(,nogrid) xtitle("Size category", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(0 "0" 1 "1-4" 2 "5-9" 3 "10-19" 4 "20-49" 5 "50-99")   
graph export "rhoyh_size_model.pdf", as(pdf) replace
graph export "rhoyh_size_model.tif", as(tif) replace

////// Figure 3 Model //////

clear
insheet laboremp noemp using  "aux_f3.csv", comma nonames
replace noemp=noemp*100

gen age=_n

twoway (line noemp age, sort lpattern(solid) lcolor(blue)) (line laboremp age, sort lpattern(dash) lcolor(red) yaxis(2)) if age<9, ///
ytitle("Fraction of non-employers (%)", size(large)) ytitle("Average labor of employers", size(large) axis(2))  ylabel(,nogrid) ylabel(75(75)300,axis(2)) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6-8" 7 "9-17"  8 "18-27") ///
legend(order(1 "Frac. non-employers" 2 "Avg. labor, employers") rows(1) region(lcolor(white)))  
graph export "laborage_model.pdf", as(pdf) replace
graph export "laborage_model.tif", as(tif) replace
  
 //// Figure 4 Model /////
clear
insheet hinitlt20 hinitgt60 linitlt20 linitgt60 logyinitlt20 logyinitgt60 using  "aux_f4.csv", comma nonames

gen age=_n
 
twoway (line hinitlt20 age, sort lpattern(solid) lcolor(blue)) (line hinitgt60 age, sort lpattern(dash) lcolor(red)), ///
ytitle("Owner hours", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Initial hours < 20" 2 "Initial hours > 60") rows(1) region(lcolor(white)))  
graph export "hinit_model.pdf", as(pdf) replace
graph export "hinit_model.tif", as(tif) replace
 
twoway (line linitlt20 age, sort lpattern(solid) lcolor(blue)) (line linitgt60 age, sort lpattern(dash) lcolor(red)), ///
ytitle("Hired labor", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Initial hours < 20" 2 "Initial hours > 60") rows(1) region(lcolor(white)))  
graph export "linit_model.pdf", as(pdf) replace
graph export "linit_model.tif", as(tif) replace
  
twoway (line logyinitlt20 age, sort lpattern(solid) lcolor(blue)) (line logyinitgt60 age, sort lpattern(dash) lcolor(red)), ///
ytitle("Output (logs)", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Initial hours < 20" 2 "Initial hours > 60") rows(1) region(lcolor(white)))  
graph export "logyinit_model.pdf", as(pdf) replace
graph export "logyinit_model.tif", as(tif) replace
  
 /////// Figure 5 ////
clear
insheet h25asset h50asset h75asset h25z h50z h75z using "aux_f5.csv", comma nonames 

gen dcile=_n
 twoway (line h50asset dcile, sort lpattern(solid) lcolor(red)) ///
 (line h25asset dcile, sort lpattern(shortdash) lcolor(red)) ///
(line h75asset dcile, sort lpattern(longdash) lcolor(red)), ///
ytitle("Owner hours", size(large))  ylabel(,nogrid) xtitle("Asset groups", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) xlabel(1(1)10) ///
legend(order(2 "P25" 1 "Median" 3 "P75") rows(1) region(lcolor(white)))  
graph export "arankh_bmpctiles.pdf", as(pdf) replace
graph export "arankh_bmpctiles.tif", as(pdf) replace
 
twoway (line h50z dcile, sort lpattern(solid) lcolor(red)) ///
 (line h25z dcile, sort lpattern(shortdash) lcolor(red)) ///
(line h75z dcile, sort lpattern(longdash) lcolor(red)), ///
ytitle("Owner hours", size(large))  ylabel(,nogrid) xtitle("Productivity groups", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) xlabel(1(1)10) ///
legend(order(2 "P25" 1 "Median" 3 "P75") rows(1) region(lcolor(white)))  
graph export "drankh_bmpctiles.pdf", as(pdf) replace
graph export "drankh_bmpctiles.tif", as(tif) replace
  
//// Figure 6 //////
clear
insheet logzrich logzpoor logzall using "aux_f6_1.csv", comma nonames
gen age=_n 
twoway (line logzrich age, sort lpattern(solid) lcolor(blue)) (line logzpoor age, sort lpattern(dash) lcolor(red)) ///
(line logzall age, sort lpattern(shortdash) lcolor(green)), ///
ytitle("Productivity, z (logs)", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Rich" 2 "Poor" 3 "All") rows(1) region(lcolor(white)))  
graph export "logzrichpoor.pdf", as(pdf) replace
graph export "logzrichpoor.tif", as(tif) replace
 
clear
insheet lognurich lognupoor lognuall using "aux_f6_2.csv", comma nonames
gen age=_n  
twoway (line lognurich age, sort lpattern(solid) lcolor(blue)) (line lognupoor age, sort lpattern(dash) lcolor(red)) ///
(line lognuall age, sort lpattern(shortdash) lcolor(green)), ///
ytitle("Disutility of working, v (logs)", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Rich" 2 "Poor" 3 "All") rows(1) region(lcolor(white)))  
graph export "logvrichpoor.pdf", as(pdf) replace
graph export "logvrichpoor.tif", as(tif) replace
    
clear
insheet hrich hpoor hall using  "aux_f6_3.csv", comma nonames
gen age=_n 
twoway (line hrich age, sort lpattern(solid) lcolor(blue)) (line hpoor age, sort lpattern(dash) lcolor(red)) ///
(line hall age, sort lpattern(shortdash) lcolor(green)), ///
ytitle("Owner hours", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Rich" 2 "Poor" 3 "All") rows(1) region(lcolor(white)))  
graph export "hrichpoor.pdf", as(pdf) replace
graph export "hrichpoor.tif", as(tif) replace
  
clear
insheet lrich lpoor lall using "aux_f6_4.csv", comma nonames
gen age=_n 
twoway (line lrich age, sort lpattern(solid) lcolor(blue)) (line lpoor age, sort lpattern(dash) lcolor(red)) ///
(line lall age, sort lpattern(shortdash) lcolor(green)), ///
ytitle("Hired labor", size(large))  ylabel(,nogrid) xtitle("Firm age", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) ///
 xlabel(1(1)8) ///
legend(order(1 "Rich" 2 "Poor" 3 "All") rows(1) region(lcolor(white)))  
graph export "lrichpoor.pdf", as(pdf) replace
graph export "lrichpoor.tif", as(tif) replace

//// Figure 7 ///

clear
insheet fracinpop10 using "f7_10.csv", comma nonames
save "temp_f7_10", replace
clear
insheet fracinpop40 using "f7_40.csv", comma nonames

merge 1:1 _n using "temp_f7_10", nogenerate

gen drank=_n
/// We know the baseline fraction of all these deciles is 0.9 (percentage of entrship in baseline / number of deciles)
gen fracinpopbase=0.9
replace fracinpop10=fracinpop10*fracinpopbase
replace fracinpop40=fracinpop40*fracinpopbase
*** Notice that the f7_10 and f7_40 give relative to baseline, so we need to scale them by 0.9 ///

twoway (line fracinpopbase drank, sort lpattern(solid) lcolor(red)) ///
 (line fracinpop10 drank, sort lpattern(shortdash) lcolor(blue)) ///
(line fracinpop40 drank, sort lpattern(longdash) lcolor(green))  , ///
ytitle("Number of owners (%)", size(large))  ylabel(,nogrid) xtitle("Asset groups", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) xlabel(1(1)10) ///
legend(order(1 "Benchmark" 2 "h{&le}10" 3 "h{&ge}40") rows(1) region(lcolor(white)))  
graph export "arankpop6.pdf", as(pdf) replace
graph export "arankpop6.tif", as(tif) replace
  
  
//// Figure 8 ///

clear
insheet fracinpop10 using "f8_10.csv", comma nonames
save "temp_f8_10", replace
clear
insheet fracinpop40 using "f8_40.csv", comma nonames

merge 1:1 _n using "temp_f8_10", nogenerate

gen drank=_n
/// We know the baseline fraction of all these deciles is 0.9 (percentage of entrship in baseline / number of deciles)
gen fracinpopbase=0.9
replace fracinpop10=fracinpop10*fracinpopbase
replace fracinpop40=fracinpop40*fracinpopbase
*** Notice that the f8_10 and f8_40 give relative to baseline, so we need to scale them by 0.9 ****

twoway (line fracinpopbase drank, sort lpattern(solid) lcolor(red)) ///
 (line fracinpop10 drank, sort lpattern(shortdash) lcolor(blue)) ///
(line fracinpop40 drank, sort lpattern(longdash) lcolor(green))  , ///
ytitle("Number of owners (%)", size(large))  ylabel(,nogrid) xtitle("Productivity groups", size(large))   ///
graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(large)) xlabel(1(1)10) ///
legend(order(1 "Benchmark" 2 "h{&le}10" 3 "h{&ge}40") rows(1) region(lcolor(white)))  
graph export "drankpop6.pdf", as(pdf) replace
graph export "drankpop6.tif", as(tif) replace
    
