clear
close all
clc
%This program solves the recalibrated model with fixed owner hours (Tables 7+8)

twotheta =0; %Set to one to double borrowing ability
%% 

% The code is written for a more general CES production function than used in the paper: [lambda h^rho+(1-lambda)L^rho]^(1/rho) where we set lambda=0.5. 
% As a consequence, mean firm productivities are rescaled.
% See main.m for more detailed comments on the program.

mue = 0.9790; 
sigma = 0.1250;
rho = 0.990;         
xi=0.0;                                        
eta = 0.88;     
if twotheta==0
    theta =0.177;     
else
    theta = 2*0.177;
end
kappaS=0.44; 
prob_w = 0.590;
sigma_w = 0.29;
beta = 0.9768;
lambda = 0.5; 
lambda2 = 1-lambda;

%unchanged
elas=0.5;
nu.mean = -1.05; 
nu.rho = 0.47;  
nu.std = 0.9;
kappa=1;     
lambdaS = 0.61; 


%worker productivity
mu_w = 0;
rho_w = 0.95;
nw = 5;
sigma2.w = (sigma_w^2)/(1-rho_w^2);
[grid_w,P_w] = Tauchen(rho_w,nw,sigma2.w,mu_w,'importance'); 
grid_w = exp(grid_w)';
prob_become_w = ones(nw,1)/nw;
prob_become_wcum = cumsum(prob_become_w);
P_wcum = cumsum(P_w,2);



phi = 2.0; 
gamma = 1.5;
delta = 0.06;
hmax=1;
nu.inov = nu.std;  


alpha = 0.33;
alpha2=1-alpha;


if twotheta==0
    r = 0.00537;
else
    r = 0.00420;
end


wage = (((alpha^alpha)*((1-alpha)^(1-alpha)))/(r+delta))^(1/(1-alpha));



%hours grid
nh = 1;
hgrid = linspace(1,1,nh)'; %owner hous restricted to 40

%productivity grid
nz = 21;
sigma2.z = (sigma^2)/(1-rho^2); %long-run variance
[Z,P] = Tauchen_asy(rho,nz,sigma2.z,mue);
z_min = min(Z);
z_max = max(Z);
log_Z=Z;
Z = exp(Z)';
Ptran = cumsum(P,2);


%grid of preferences
nnu = 6;
sigma2.nu = (nu.std^2)/(1-nu.rho^2);
[nu.grid,nu.P] = Tauchen(nu.rho,nnu,sigma2.nu,nu.mean,'importance'); 
nu.grid=nu.grid';
nu.tran = cumsum(nu.P,2);
nu_min = min(nu.grid);
nu_max = max(nu.grid);

nu.grid_log = nu.grid;
nu.min = min(nu.grid);
nu.max = max(nu.grid);
nu.grid = exp(nu.grid);


%compute largest possible firm (optimal unconstrained choice):
lgrid = linspace(0,500,400)';
Xgrid = (lambda*(hmax^elas)+lambda2*(lgrid.^elas)).^(1/elas);

aux1=alpha*eta/(r+delta);
aux3 = 1/(1-alpha*eta);
aux4 = alpha2*eta/(1-alpha*eta);
aux5 = elas/(1-elas);

Yaux = (Z(end)*(aux1^(alpha*eta))*Xgrid.^(alpha2*eta)).^aux3;
Kaux = Yaux*aux1;
PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
[~,index] = max(PIaux);
Y_max=Yaux(index);
K_max = Kaux(index);
L_max = lgrid(index)
if L_max>400
    L_max=400;
    Y_max = L_max*wage/(alpha2*eta);
    K_max = alpha*eta*Y_max/(r+delta);
end

%asset grid
amin = 0.01;
amax = max(6*wage,(K_max*(r+delta)+wage*L_max+xi)/theta);
na = 244;
agrid = [amin; wage/15; wage/10; wage/9; wage/8; wage/7; wage/6; wage/5; wage/4; wage/3; wage/2; wage; wage*1.5; wage*2; wage*2.5; wage*3; wage*3.5; wage*4; wage*5; wage*6; wage*7;];
aux = linspace(wage*7,amax/10,(na/2)-19)';
agrid = [agrid; aux(2:end)];
aux = linspace(amax/10,amax,ceil(na/2+1))';
agrid = [agrid; aux(2:end)];
na = na+1;

%grid of asset choices (larger than agrid)
diffa=diff(agrid);
diffa2=diffa/9;
agridp=zeros(9*na-8,1);
for i =1:na-1
    agridp(1+9*(i-1):9*i,1) = agrid(i)+(0:8)'*diffa2(i);
end
agridp(end)=agrid(end);
nap = length(agridp);
[~,xia] = histc(agridp,agrid); %find lower bounds on asset grid
xia(agridp<agrid(1)) = 1;
xia(agridp>=agrid(end)) = na-1;
sia = (agridp - agrid(xia))./diffa(xia);


lgrid = linspace(0,L_max,400)';

%minimum consumption
sub = 10^(-100);

%% solve for posible static choices


L = zeros(na,nz,nh,4);
K = zeros(na,nz,nh,4);
Yin = zeros(na,nz,nh,4);
Cin = zeros(na,nz,nh,4);

%loop over states
for i = 1:na
    aux6 = theta*agrid(i)-xi;
    for j = 1:nz
        for i2 = 1:nh %loop of hours choice
            h = hgrid(i2);
            
            Xgrid = (lambda*(h^elas)+lambda2*(lgrid.^elas)).^(1/elas);
            %case 1: L>0 FC do not bind
            if aux6>0.0001
                Yaux = (Z(j)*(aux1^(alpha*eta))*Xgrid.^(alpha2*eta)).^aux3;
                Kaux = Yaux*aux1;
                upper = (aux6-wage*lgrid)/(r+delta);
                index = Kaux>upper;
                Yaux(index) = 0;
                PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
                [~,index] = max(PIaux);
                Yin(i,j,i2,1)=Yaux(index);
                K(i,j,i2,1)=Kaux(index);
                L(i,j,i2,1) = lgrid(index);
                Cin(i,j,i2,1)=(r+delta)*Kaux(index)+wage*lgrid(index);
            else
                Yin(i,j,i2,1)=-1000;
            end
            
            %case 2: L>0, FC bind
            if aux6>0.0001
                Kaux = (aux6-wage*lgrid)/(r+delta);
                Kaux(Kaux<0) = 0;
                Yaux = Z(j)*(Kaux.^(alpha*eta)).*(Xgrid.^(alpha2*eta));
                PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
                [~,index] = max(PIaux);
                Yin(i,j,i2,2)=Yaux(index);
                K(i,j,i2,2)=Kaux(index);
                L(i,j,i2,2) = lgrid(index);
                Cin(i,j,i2,2)=(r+delta)*Kaux(index)+wage*lgrid(index);
            else
                Yin(i,j,i2,2)=-1000;
            end
            
            if h==0
                Yin(i,j,i2,3)=-1000;
                Yin(i,j,i2,4)=-1000;
            else
                %case 3: lm=0,lb=0, FC no bind
                y=(Z(j)*(aux1^(alpha*eta))*((kappaS*h)^(lambdaS*eta)))^aux3;
                kk = aux1*y;
                upper = (theta*agrid(i))/(r+delta);
                if (kk/upper>1.005 && (kk-upper)>0.01)
                    y=0;
                end
                Cin(i,j,i2,3) = (r+delta)*kk;
                Yin(i,j,i2,3)=y;
                K(i,j,i2,3)=kk;
                L(i,j,i2,3) = 0;
                
                %case 6: lm=0,lb=0 FC bind
                y=Z(j)*(((aux6+xi)/(r+delta))^(alpha*eta))*((kappaS*h)^(lambdaS*eta));
                kk = (aux6+xi)/(r+delta);
                Cin(i,j,i2,4) = (r+delta)*kk;
                Yin(i,j,i2,4)=y;
                K(i,j,i2,4)=kk;
                L(i,j,i2,4) = 0;
            end
        end
    end
end

%% VFI

%consumption choices of workers
consumew = (1+r)*repmat(agrid,[1 nap nw])-repmat(agridp',[na 1 nw])+wage*repmat(reshape(grid_w,[1 1 nw]),[na nap 1]);
consumew = max(consumew,sub);
consumew = log(consumew);

%disutility of working for workers and owners
hwutil = ((1.^(1+phi))./(1+phi));
heutil = ((hgrid.^(1+phi))./(1+phi));

%profits
PI=Yin-Cin;
PImax = zeros(na,nz);
for i =1:na
    for j = 1:nz
        PImax(i,j) = max(max(max(PI(i,j,:,:))));
    end
end

%static optimal labor choice
[PI_opt,index_l] = max(PI,[],4);


%guess labor and capital policy functions and value function
load('V_counter.mat','V_counter')
load('Vw_counter.mat','Vw_counter')

Vold_e = V_counter;
Vold_w = Vw_counter;

% Vold_e = zeros(na,nz,nnu,nw);
% Vold_w = zeros(na,nz,nnu,nw);


crit=1;
while crit>5*10^(-3)
    
    %employment decisions
    Echoice = Vold_e>Vold_w;
    
    EVE_e = (prob_w*max(Vold_e,Vold_w)+(1-prob_w)*Vold_e);
    EVE_w = max(Vold_e,Vold_w);
    
    %worker
    [Vw,index_w_h,index_w_a] = VFI_w_mex(EVE_w,consumew,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,hgrid,beta,gamma,phi,sub,r,wage,P,nu.P,int32(xia),sia,hwutil,P_w);
    
    %owner
    [V,index_a,index_h] = VFI_e4_mex(EVE_e,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,beta,gamma,sub,r,P,nu.P,P_w,int32(xia),sia,heutil,PI,PImax,PI_opt,hgrid,hmax);
    
    
    crit1 = max(max(max(max(abs(V-Vold_e)))));
    crit2 = max(max(max(max(abs(Vw-Vold_w)))));
    crit = max([crit1 crit2]);
    Vold_e = V;
    Vold_w = Vw;
    
end
V_counter=Vold_e;
Vw_counter=Vold_w;
save('V_counter.mat','V_counter')
save('Vw_counter.mat','Vw_counter')


%policies
lchoice = zeros(na,nz,nnu,nw);
hchoice = zeros(na,nz,nnu,nw);
kchoice = zeros(na,nz,nnu,nw);
aprime_e = zeros(na,nz,nnu,nw);
hchoice_w = zeros(na,nz,nnu,nw);
aprime_w = zeros(na,nz,nnu,nw);
for i = 1:na
    for l = 1:nnu
        for j = 1:nz
            for k =1:nw
                aprime_e(i,j,l,k) = agridp(index_a(i,j,l,k));
                hchoice(i,j,l,k) = hgrid(index_h(i,j,l,k));
                lchoice(i,j,l,k) = L(i,j,index_h(i,j,l,k),index_l(i,j,index_h(i,j,l,k)));
                kchoice(i,j,l,k) = K(i,j,index_h(i,j,l),index_l(i,j,index_h(i,j,l,k)));
                hchoice_w(i,j,l,k) = 1;
                aprime_w(i,j,l,k) = agridp(index_w_a(i,j,l,k));
            end
        end
    end
end


Y = output_ces(alpha,lambda,eta,elas,repmat(reshape(Z,[1 nz 1]),[na 1 nnu nw]),kchoice,lchoice,hchoice);
for i=1:na
    for j =1:nz
        for k = 1:nnu
            for l = 1:nw
                if (lchoice(i,j,k,l))==0
                    Y(i,j,k,nw) = Z(j)*(kchoice(i,j,k,l).^(alpha*eta))*(kappaS*(hchoice(i,j,k,l)))^(lambdaS*eta);
                end
            end
        end
    end
end
Costs = (r+delta)*kchoice+wage*lchoice+(lchoice>0)*xi;

%profits and consumption
PII = Y-Costs;
CC_e = zeros(na,nz,nnu,nw);
CC_w = zeros(na,nz,nnu,nw);
for i = 1:na
    for l = 1:nnu
        for j = 1:nz
            for k = 1:nw
                CC_e(i,j,l,k) = (1+r)*agrid(i)-aprime_e(i,j,l,k)+PII(i,j,l,k);
                CC_w(i,j,l,k) = (1+r)*agrid(i)-aprime_w(i,j,l,k)+hchoice_w(i,j,l,k)*wage*grid_w(k);
            end
        end
    end
end



%% Simulation
H=10000; %number of individuals
T=500; %number of periods
rand('seed',262524);
randn('seed',276624);

z_shock = sigma*randn(H,T);
nu_shock = nu.std*randn(H,T);
job_shock = rand(H,T);
w_shock = rand(H,T);


%initialization
load('panel_ergo.mat','panel_ergo')
panel = zeros(H,12,100); %prod, nu, A, w, C, Y, h, l, K, type1, age, ID

panel(:,12,1) =1:H;
panel(:,1,1) =panel_ergo(:,1);
panel(:,2,1) =panel_ergo(:,2);
panel(:,3,1) =panel_ergo(:,3);
panel(:,4,1) =panel_ergo(:,4);
panel(:,10,1) =panel_ergo(:,10);
panel(panel_ergo(:,10)==2,11,1) =1;



for t1=1:T-1 %keep simulating
    
    %lower grid points for state
    [~,xii] = histc(panel(:,3,t1),agrid); %find lower bounds assets
    xii(panel(:,3,t1)<=agrid(1)) = 1;
    xii(panel(:,3,t1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1),log_Z); %find lower bounds assets
    yii(panel(:,1,t1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1)>=log_Z(end)) = nz-1;
    [~,zii] = histc(panel(:,2,t1),nu.grid_log); %find lower bounds assets
    zii(panel(:,2,t1)<=nu.grid_log(1)) = 1;
    zii(panel(:,2,t1)>=nu.grid_log(end)) = nnu-1;
    
    %productivity next period
    panel(:,1,t1+1) = min(z_max+0.08,max(z_min-0.08,rho*panel(:,1,t1)+(1-rho)*mue+z_shock(:,t1)));
    
    %leissure next period
    panel(:,2,t1+1) = min(nu_max+0.2,max(nu_min-0.2,nu.rho*panel(:,2,t1)+(1-nu.rho)*nu.mean+nu_shock(:,t1)));
    
    for i1 = 1:H
        %asset,labor,hours choice
        if panel(i1,10,t1) == 1 %worker
            panel(i1,7,t1) = 1;
            panel(i1,3,t1+1) = interp3_l(agrid,log_Z,nu.grid_log,aprime_w(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1));
            panel(i1,6,t1) = wage;
        else
            panel(i1,7,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,hchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,8,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,lchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,9,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,kchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,3,t1+1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,aprime_e(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            if panel(i1,8,t1)>0
                panel(i1,6,t1) = output_ces(alpha,lambda,eta,elas,exp(panel(i1,1,t1)),panel(i1,9,t1),panel(i1,8,t1),panel(i1,7,t1));
            else
                panel(i1,6,t1) = exp(panel(i1,1,t1))*((panel(i1,9,t1).^(alpha*eta)))*((kappaS*panel(i1,7,t1))^(lambdaS*eta));
            end
        end
    end
    
    %next period states
    [~,xii] = histc(panel(:,3,t1+1),agrid); %find lower bounds assets
    xii(panel(:,3,t1+1)<=agrid(1)) = 1;
    xii(panel(:,3,t1+1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1+1),log_Z); %find lower bounds assets
    yii(panel(:,1,t1+1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1+1)>=log_Z(end)) = nz-1;
    [~,zii] = histc(panel(:,2,t1+1),nu.grid_log); %find lower bounds assets
    zii(panel(:,2,t1+1)<=nu.grid_log(1)) = 1;
    zii(panel(:,2,t1+1)>=nu.grid_log(end)) = nnu-1;
    for i1 = 1:H
        %type transition
        panel(i1,4,t1+1) = sum(w_shock(i1,t1)>P_wcum(panel(i1,4,t1),:))+1;
        if panel(i1,10,t1) == 1 %worker
            echoice = interp3_l(agrid,log_Z,nu.grid_log,Echoice(:,:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),panel(i1,2,t1+1),xii(i1),yii(i1),zii(i1));
            if echoice<=0.5
                panel(i1,10,t1+1) = 1;
            else
                panel(i1,10,t1+1) = 2;
                panel(i1,11,t1+1) = 1; 
            end
        else
            if job_shock(i1,t1)<prob_w %can become worker
                echoice = interp3_l(agrid,log_Z,nu.grid_log,Echoice(:,:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),panel(i1,2,t1+1),xii(i1),yii(i1),zii(i1));
                if echoice>0.5
                    panel(i1,10,t1+1) = 2;
                    panel(i1,11,t1+1) = panel(i1,11,t1)+1;
                else
                    panel(i1,10,t1+1) = 1;
                end
            else
                panel(i1,10,t1+1) = 2;
                panel(i1,11,t1+1) = panel(i1,11,t1)+1;
            end
        end
    end
end

panel(:,12,end) =1:H;
panel = panel(:,:,101:T);
for t1 = 1:T-100
    prod(t1,1) = mean(panel(:,1,t1));
    leis(t1,1) = mean(panel(:,2,t1));
    share_e(t1,1) = mean(panel(:,10,t1)==2);
    supply_a(t1,1) = sum(panel(:,3,t1));
    demand_a(t1,1) = sum(panel(:,9,t1));
    supply_w(t1,1) = sum(grid_w(panel(panel(:,10,t1)==1,4,t1)));
    demand_w(t1,1) = sum(panel(:,8,t1));
end


%equilibrium
net_supply.w = mean(supply_w-demand_w)/H;
net_supply.a = mean(supply_a-demand_a)/H


ratio1 = net_supply.w/net_supply.a;
alpha/(1-alpha)*wage*ratio1-delta %equilibrium interest rate. Should match guess


%% Statistics

panel2 = zeros(H*(T-100),12);
for h = 1:H
    transform = squeeze(panel(h,:,1:end));
    transform = transform';
    panel2(1+(h-1)*(T-100):h*(T-100),:) = transform;
end
panel = panel2;
clear panel2

%autocorrlation of hours and transition from employment to self
clear aux
aux(:,1) = panel(:,7)*40;
aux(:,2)=panel(:,10)==2;
aux(:,3)=panel(:,12);
fcn = @(x){create_lag(x,1)};
aux(:,4) = accumarray_expand(aux(:,2),aux(:,3),fcn);%lagged employment status
aux(:,5) = accumarray_expand(aux(:,1),aux(:,3),fcn);%lagged hours
fcn = @(x){diff_l(x)};
aux(:,6) = accumarray_expand(aux(:,2),aux(:,3),fcn);%diff employment status
fcn = @(x){create_lead(x,1)};
aux(:,6) = accumarray_expand(aux(:,6),aux(:,3),fcn);
aux2=aux(aux(:,2)==1,:);
aux2=aux2(aux2(:,4)==1,:);
h_autocorr = corr(aux2(:,1),aux2(:,5));
aux2 = aux(isnan(aux(:,6))==0,:);
aux2 = aux2(aux2(:,2)==0,6);
prob_es = mean(aux2);

%survive for first 8 years
aux = panel(panel(:,10)==2,:);
aux = aux(aux(:,11)<1000,:);
entry_survive = zeros(10,1);
for t1 = 1:10
    entry_survive(t1,1) = sum(aux(:,11)==t1);
end
entry_survive = entry_survive./entry_survive(1);

index = logical((panel(:,10)==2).*(panel(:,7)>0));
share_e=mean(index);
firms = panel(index==1,:);

%hours
firms(:,13) = 0; %size category
index = firms(:,8)==0;
firms(index,13) = 1;
index = (firms(:,8)>=0.5).*(firms(:,8)<4.5);
firms(logical(index),13) = 2;
index = (firms(:,8)>=4.5).*(firms(:,8)<9.5);
firms(logical(index),13) = 3;
index = (firms(:,8)>=9.5).*(firms(:,8)<19.5);
firms(logical(index),13) = 4;
index = (firms(:,8)>=19.5).*(firms(:,8)<49.5);
firms(logical(index),13) = 5;
index = firms(:,8)>=49.5;
firms(logical(index),13) = 6;

%profits
firms(:,14) = firms(:,6)-wage*firms(:,8)-(r+delta)*firms(:,9);


index = firms(:,8)==0; %non-employers
ave.all.f0=mean(index); %share of non-employers
employers = firms(index==0,:);
self = firms(index==1,:);
workers = panel(panel(:,10)==1,:);


ave.employer.l=mean(employers(:,8)*40); %average employer size
prct.employer.l.p95=prctile(employers(:,8),95)*40; %95th percentile
st.firms.h=std(log(firms(:,7)*40));
ave.employer.h=mean(employers(:,7))*40; %average hours among employers
ave.self.h=mean(self(:,7))*40; %average hours of non-employers
wealth_income = sum(panel(:,3))./(sum(firms(:,14))+sum(workers(:,6).*grid_w(workers(:,4))));

%average age
aux = firms(firms(:,11)<1000,11);
ave_age = mean(aux);

%workers' income inequality
worker_inc = wage*grid_w(workers(:,4));
worker_disp.gini = ginicoeff(worker_inc);


calibration_targets = [share_e; 
    ave_age;
    prct.employer.l.p95;
entry_survive(5);
ave.employer.l;
ave.all.f0;
worker_disp.gini;
wealth_income];


%% Wealth inequality

aux= firms(firms(:,3)>amin,3);
wealth.entre.std=std(log(aux));
    

%Owner relative to worker wealth
top25_ent = prctile(firms(:,3),75);
top75_ent = prctile(firms(:,3),25);
wealth.entre.r7525=top25_ent/top75_ent;


%% compute further moments


%degree of finacial frictions
aux = firms(firms(:,11)<900,:);
index = (aux(:,8))==0;
aux_s = aux(index,:);
aux_s(:,15) = (r+delta)*aux_s(:,9)+xi>=0.95*theta*aux_s(:,3);
aux_s = sortrows(aux_s,11);
aux_e = aux(index==0,:);
aux_e(:,15) = wage*aux_e(:,8)+(r+delta)*aux_e(:,9)+xi>=0.95*theta*aux_e(:,3);
aux_e = sortrows(aux_e,11);
aux_all = [aux_s; aux_e];
pos1=(exp(aux_all(:,1)).*((alpha*eta/(r+delta))^(alpha*eta)).*((kappaS*aux_all(:,7)).^(lambdaS*eta))).^(1/(1-alpha*eta)); %output
pos1(:,2) = ((alpha*eta/(r+delta))*pos1*(r+delta))/theta; %required assets
pos1(:,1) = pos1(:,1)-(r+delta)*(alpha*eta/(r+delta))*pos1(:,1); %profits from self-employment
pos2 = zeros(length(aux_all),2);
for i1 = 1:length(aux_all)
    Xgrid = (lambda*(aux_all(i1,7)^elas)+lambda2*(lgrid.^elas)).^(1/elas);
    Yaux = (exp(aux_all(i1,1))*((alpha*eta/(r+delta))^(alpha*eta))*Xgrid.^(alpha2*eta)).^(1/(1-alpha*eta));
    Kaux = Yaux*(alpha*eta/(r+delta));
    PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
    [pos2(i1,1),index] = max(PIaux);
    pos2(i1,2) = (Kaux(index)*(r+delta)+wage*lgrid(index))/theta; %required assets
end
all = [pos1(:,1) pos2(:,1)];
[~,index] = max(all,[],2);
assets_opt = zeros(length(aux_all),1);
for i1 = 1:length(aux_all)
    if index(i1)==1
        assets_opt(i1) = pos1(i1,2);
    else
        assets_opt(i1) = pos2(i1,2);
    end
end
aux_all(:,16) = assets_opt./aux_all(:,3);
aux_all(:,17) = (assets_opt-aux_all(:,3))./(wage);
aux_all = sortrows(aux_all,11);
share_con = mean(aux_all(:,15));



%Table 8
total_output = sum(firms(:,6));
total_labor = sum(firms(:,8));
total_wealth = sum(firms(:,3));
   