clear
close all
clc
%This program solves the recalibrated model without owner hours (Tables 7+8)

twotheta =0; %set to 1 to double borrowing ability
%% 

% The code is written for a more general CES production function than used in the paper: [lambda h^rho+(1-lambda)L^rho]^(1/rho) where we set lambda=0.5. 
% As a consequence, mean firm productivities are rescaled.
% See main.m for more detailed comments on the program.

mue = 0.12;
sigma = 0.400; 
rho = 0.952;         
xi=0.0;                                         
if twotheta==0
    theta = 0.244*0.5;     %financial friction (firm growth) 
else
    theta = 2*0.244*0.5;
end
prob_w = 0.490;
sigma_w = 0.28;
beta = 0.9740;
lambda = 0.5; 
lambda2 = 1-lambda;
elas=0.5;

nu.mean = -1.05; %average log disutility (average hours worked managers)

nu.rho = 0.0001;   %autocorrelation of log leissure   
nu.std = 0.00001;   %std of log disitulity (hour dispersion)


%worker productivity
mu_w = 0;
rho_w = 0.95;
nw = 5;
sigma2.w = (sigma_w^2)/(1-rho_w^2);
[grid_w,P_w] = Tauchen(rho_w,nw,sigma2.w,mu_w,'importance'); 
grid_w = exp(grid_w)';
prob_become_w = ones(nw,1)/nw;
prob_become_wcum = cumsum(prob_become_w);
P_wcum = cumsum(P_w,2);


phi = 2.0; 
gamma = 1.5;
delta = 0.06;
hmax=2.25;
nu.inov = nu.std;  

eta = 0.88;    
alpha = 0.33;
alpha2=1-alpha;


if twotheta==0
    r = -0.00440;
else
    r = -0.01185;
end

wage = (((alpha^alpha)*((1-alpha)^(1-alpha)))/(r+delta))^(1/(1-alpha));



%hours grid
nh = 1;
hgrid = linspace(0,0,nh)'; %hours restricted to be 0

%productivity grid
nz = 41;
sigma2.z = (sigma^2)/(1-rho^2); %long-run variance
[Z,P] = Tauchen_asy(rho,nz,sigma2.z,mue);
% [Z,P] = Tauchen(rho,nz,sigma2.z,mue,'equi');
z_min = min(Z);
z_max = max(Z);
log_Z=Z;
Z = exp(Z)';
Ptran = cumsum(P,2);



%grid of preferences
nnu = 1;
sigma2.nu = (nu.std^2)/(1-nu.rho^2);
if nnu >1
    [nu.grid,nu.P] = Tauchen(nu.rho,nnu,sigma2.nu,nu.mean,'importance'); 
else
    nu.grid=nu.mean;
    nu.P=1;
end
nu.grid=nu.grid';
nu.tran = cumsum(nu.P,2);
nu_min = min(nu.grid);
nu_max = max(nu.grid);

nu.grid_log = nu.grid;
nu.min = min(nu.grid);
nu.max = max(nu.grid);
nu.grid = exp(nu.grid);


%compute largest possible firm (optimal unconstrained choice):
aux1 = ((alpha*eta)/(r+delta))^(alpha*eta);
aux2 = ((alpha2*eta)/wage)^(alpha2*eta);
Y_max=(exp(log_Z(end))*aux1*aux2)^(1/(1-alpha*eta-alpha2*eta));
K_max = alpha*eta*Y_max/(r+delta);
K_max = min(K_max,1000);
L_max = alpha2*eta*Y_max/wage
if L_max>500
    L_max=500;
    Y_max = L_max*wage/(alpha2*eta);
    K_max = alpha*eta*Y_max/(r+delta);
end


%asset grid
amin = 0.01;
amax = max(6*wage,(K_max*(r+delta)+wage*L_max+xi)/theta);
na = 344;
agrid = [amin; wage/15; wage/10; wage/9; wage/8; wage/7; wage/6; wage/5; wage/4; wage/3; wage/2; wage; wage*1.5; wage*2; wage*2.5; wage*3; wage*3.5; wage*4; wage*5; wage*6; wage*7;];
aux = linspace(wage*7,amax/10,(na/2)-19)';
agrid = [agrid; aux(2:end)];
aux = linspace(amax/10,amax,ceil(na/2+1))';
agrid = [agrid; aux(2:end)];
na = na+1;

%grid of asset choices (larger than agrid)
diffa=diff(agrid);
diffa2=diffa/9;
agridp=zeros(9*na-8,1);
for i =1:na-1
    agridp(1+9*(i-1):9*i,1) = agrid(i)+(0:8)'*diffa2(i);
end
agridp(end)=agrid(end);
nap = length(agridp);
[~,xia] = histc(agridp,agrid); %find lower bounds on asset grid
xia(agridp<agrid(1)) = 1;
xia(agridp>=agrid(end)) = na-1;
sia = (agridp - agrid(xia))./diffa(xia);


%minimum consumption
sub = 10^(-100);

%% solve for posible static choices

L = zeros(na,nz,2);
K = zeros(na,nz,2);
Yin = zeros(na,nz,2);
Cin = zeros(na,nz,2);

aux1 = (alpha*eta/(r+delta))^(alpha*eta);
aux2 = ((alpha2*eta)/wage)^(alpha2*eta);
aux3 = (alpha/(r+delta))^(alpha*eta);
aux4 = ((alpha2)/wage)^(alpha2*eta);
%loop over states
for i = 1:na
    aux6 = theta*agrid(i)-xi;
    for j = 1:nz

        %case 1: lm>0,lb>0, FC no bind
        if aux6>0.0001
            y=(exp(log_Z(j))*aux1*aux2)^(1/(1-eta));
            kk = (alpha*eta)/(r+delta)*y;
            l = (alpha2*eta)/wage*y;
            if l<0
                l = 0;
                y=-1000;
            end
            upper = (aux6-wage*l)/(r+delta);
            if (kk/upper>1.005 && (kk-upper)>0.01) || upper<0
                y=-10000;
            end
            if l>0
                Cin(i,j,1) = wage*l+(r+delta)*kk+xi;
            else
                Cin(i,j,1) = (r+delta)*kk;
            end
            Yin(i,j,1)=y;
            K(i,j,1)=kk;
            L(i,j,1) = l;
        else
            Yin(i,j,1)=0;
        end
        
        %case 2: lm>0,lb>0, FC bind
        if aux6>0.0001
            y=Z(j)*(aux6^eta)*aux3*aux4;
            kk = (aux6*alpha)/(r+delta);
            l = (aux6*alpha2)/wage;
            upper = (aux6-wage*l)/(r+delta);
            if (kk/upper>1.005 && (kk-upper)>0.01) && l>0 
                xxx
            end
            if (kk/upper>1.005 && (kk-upper)>0.01) || upper<0
                y=-1000;
            end
            if l>0
                Cin(i,j,2) = wage*l+(r+delta)*kk+xi;
            else
                Cin(i,j,2) = (r+delta)*kk;
            end
            Yin(i,j,2)=y;
            K(i,j,2)=kk;
            L(i,j,2) = l;
        else
            Yin(i,j,2)=0;
        end
    end
end

%% VFI

%disutility of working for workers and owners
hwutil = ((1.^(1+phi))./(1+phi));
heutil=0;

%consumption choices of workers
consumew = (1+r)*repmat(agrid,[1 nap nw])-repmat(agridp',[na 1 nw])+wage*repmat(reshape(grid_w,[1 1 nw]),[na nap 1]);
consumew = max(consumew,sub);
consumew = log(consumew)-nu.grid*hwutil;

%profits
PI=Yin-Cin;
PImax = zeros(na,nz);
for i =1:na
    for j = 1:nz
        PImax(i,j) = max(max(max(PI(i,j,:))));
    end
end

%static optimal labor choice
[PI_opt,index_l] = max(PI,[],3);



%guess labor and capital policy functions and value function
load('V_counter2.mat','V_counter2')
load('Vw_counter2.mat','Vw_counter2')

Vold_e = V_counter2;
Vold_w = Vw_counter2;


crit=1;
while crit>10^(-4)
    
    %employment decisions
    Echoice = Vold_e>Vold_w;
    
    EVE_e = (prob_w*max(Vold_e,Vold_w)+(1-prob_w)*Vold_e);
    EVE_w = max(Vold_e,Vold_w);
    
    %worker
    [Vw,index_w_a] = VFI_w2_mex(EVE_w,consumew,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,hgrid,beta,gamma,phi,sub,r,wage,P,nu.P,int32(xia),sia,hwutil,P_w);
    
    %owners
    [V,index_a] = VFI_e42_mex(EVE_e,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,beta,gamma,sub,r,P,nu.P,P_w,int32(xia),sia,heutil,PI,PImax,PI_opt,hgrid,hmax);
    
    
    crit1 = max(max(max(max(abs(V-Vold_e)))));
    crit2 = max(max(max(max(abs(Vw-Vold_w)))));
    crit = max([crit1 crit2]);
    Vold_e = V;
    Vold_w = Vw;
    
end

V_counter2=V;
Vw_counter2=Vw;
save('V_counter2.mat','V_counter2')
save('Vw_counter2.mat','Vw_counter2')


%policies
lchoice = zeros(na,nz,nw);
hchoice = zeros(na,nz,nw);
kchoice = zeros(na,nz,nw);
aprime_e = zeros(na,nz,nw);
hchoice_w = zeros(na,nz,nw);
aprime_w = zeros(na,nz,nw);
for i = 1:na
        for j = 1:nz
            for k =1:nw
                aprime_e(i,j,k) = agridp(index_a(i,j,k));
                lchoice(i,j,k) = L(i,j,index_l(i,j));
                kchoice(i,j,k) = K(i,j,index_l(i,j));
                aprime_w(i,j,k) = agridp(index_w_a(i,j,k));
            end
        end
end


Y = repmat(reshape(Z,[1 nz 1]),[na 1 nw]).*(((kchoice.^alpha).*(lchoice.^alpha2)).^eta);
Costs = (r+delta)*kchoice+wage*lchoice+(lchoice>0)*xi;

%profits and consumption
PII = Y-Costs;
CC_e = zeros(na,nz,nw);
CC_w = zeros(na,nz,nw);
for i = 1:na
    for j = 1:nz
        for k = 1:nw
            CC_e(i,j,k) = (1+r)*agrid(i)-aprime_e(i,j,k)+PII(i,j,k);
            CC_w(i,j,k) = (1+r)*agrid(i)-aprime_w(i,j,k)+wage*grid_w(k);
        end
    end
end



%% Simulation
H=10000; %number of individuals
T=700; %time periods
rand('seed',262524);
randn('seed',276624);

z_shock = sigma*randn(H,T);
job_shock = rand(H,T);
w_shock = rand(H,T);


%initialization
load('panel_ergo.mat','panel_ergo')
panel = zeros(H,12,100); %prod, nu, A, w, C, Y, h, l, K, type1, age, ID

panel(:,12,1) =1:H;
panel(:,1,1) =panel_ergo(:,1);
panel(:,2,1) =0;
panel(:,3,1) =panel_ergo(:,3);
panel(:,4,1) =panel_ergo(:,4);
panel(:,10,1) =panel_ergo(:,10);
panel(panel_ergo(:,10)==2,11,1) =1;



for t1=1:T-1 %keep simulating
    
    %lower grid points for state
    [~,xii] = histc(panel(:,3,t1),agrid); %find lower bounds assets
    xii(panel(:,3,t1)<=agrid(1)) = 1;
    xii(panel(:,3,t1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1),log_Z); %find lower bounds assets
    yii(panel(:,1,t1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1)>=log_Z(end)) = nz-1;
    
    %productivity next period
    panel(:,1,t1+1) = min(z_max+0.08,max(z_min-0.08,rho*panel(:,1,t1)+(1-rho)*mue+z_shock(:,t1)));
    
    %leissure next period
    panel(:,2,t1+1) = 0;
    
    for i1 = 1:H
        %asset,labor,hours choice
        if panel(i1,10,t1) == 1 %worker
            panel(i1,7,t1) = 0;
            panel(i1,3,t1+1) = interp2_l(agrid,log_Z,aprime_w(:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),xii(i1),yii(i1));
            panel(i1,6,t1) = wage;
        else
            panel(i1,7,t1) = 0;
            panel(i1,8,t1) = max(0,interp2_l(agrid,log_Z,lchoice(:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),xii(i1),yii(i1)));
            panel(i1,9,t1) = max(0,interp2_l(agrid,log_Z,kchoice(:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),xii(i1),yii(i1)));
            panel(i1,3,t1+1) = max(0,interp2_l(agrid,log_Z,aprime_e(:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),xii(i1),yii(i1)));
            panel(i1,6,t1) = exp(panel(i1,1,t1))*(((panel(i1,9,t1).^alpha).*(panel(i1,8,t1).^alpha2)).^eta);
        end
    end
    
    %next period states
    [~,xii] = histc(panel(:,3,t1+1),agrid); %find lower bounds assets
    xii(panel(:,3,t1+1)<=agrid(1)) = 1;
    xii(panel(:,3,t1+1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1+1),log_Z); %find lower bounds assets
    yii(panel(:,1,t1+1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1+1)>=log_Z(end)) = nz-1;

    for i1 = 1:H
        %type transition
        panel(i1,4,t1+1) = sum(w_shock(i1,t1)>P_wcum(panel(i1,4,t1),:))+1;
        if panel(i1,10,t1) == 1 %worker
            echoice = interp2_l(agrid,log_Z,Echoice(:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),xii(i1),yii(i1));
            if echoice<=0.5
                panel(i1,10,t1+1) = 1;
            else
                panel(i1,10,t1+1) = 2;
                panel(i1,11,t1+1) = 1; 
            end
        else
            if job_shock(i1,t1)<prob_w %can become worker
                echoice = interp2_l(agrid,log_Z,Echoice(:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),xii(i1),yii(i1));
                if echoice>0.5
                    panel(i1,10,t1+1) = 2;
                    panel(i1,11,t1+1) = panel(i1,11,t1)+1;
                else
                    panel(i1,10,t1+1) = 1;
                end
            else
                panel(i1,10,t1+1) = 2;
                panel(i1,11,t1+1) = panel(i1,11,t1)+1;
            end
        end
    end
end

panel(:,12,end) =1:H;
panel = panel(:,:,301:T);
for t1 = 1:T-300
    prod(t1,1) = mean(panel(:,1,t1));
    leis(t1,1) = mean(panel(:,2,t1));
    share_e(t1,1) = mean(panel(:,10,t1)==2);
    supply_a(t1,1) = sum(panel(:,3,t1));
    demand_a(t1,1) = sum(panel(:,9,t1));
    supply_w(t1,1) = sum(grid_w(panel(panel(:,10,t1)==1,4,t1)));
    demand_w(t1,1) = sum(panel(:,8,t1));
end


%equilibrium
net_supply.w = mean(supply_w-demand_w)/H;
net_supply.a = mean(supply_a-demand_a)/H;


ratio1 = net_supply.w/net_supply.a;
alpha/(1-alpha)*wage*ratio1-delta %equilibrium interest rate. Should match guess


%% Statistics

panel2 = zeros(H*(T-300),12);
for h = 1:H
    transform = squeeze(panel(h,:,1:end));
    transform = transform';
    panel2(1+(h-1)*(T-300):h*(T-300),:) = transform;
end
panel = panel2;
clear panel2


%autocorrlation of hours and transition from employment to self
h_autocorr = NaN;

%survive for first 8 years
aux = panel(panel(:,10)==2,:);
aux = aux(aux(:,11)<1000,:);
entry_survive = zeros(10,1);
for t1 = 1:10
    entry_survive(t1,1) = sum(aux(:,11)==t1);
end
entry_survive = entry_survive./entry_survive(1);

index = logical((panel(:,10)==2));
share_e=mean(index);
firms = panel(index==1,:);

%hours
firms(:,13) = 0; %size category


%profits
firms(:,14) = firms(:,6)-wage*firms(:,8)-(r+delta)*firms(:,9);


% index = logical((panel(:,11)==3));
ave.all.f0=NaN;
workers = panel(panel(:,10)==1,:);
ave.worker.w = mean(wage*grid_w(workers(:,4)));
ave.worker.a = mean(workers(:,3));
ave.worker.nu = mean(workers(:,2));
ave.worker.z = mean(workers(:,1));
ave.worker.a_med = median(workers(:,3));
ave.worker.w_med = median(wage*grid_w(workers(:,4)));
ave.worker.nu_med = median(workers(:,2));
ave.worker.z_med = median(workers(:,1));
ave.all.a = mean(panel(:,3));
ave.firms.a = mean(firms(:,3));
ave.firms.y = mean(firms(:,6));
ave.firms.z = mean(exp(firms(:,1)));


ave.employer.l=mean(firms(:,8)*40);
prct.employer.l.p90=prctile(firms(:,8),90)*40;
prct.employer.l.p95=prctile(firms(:,8),95)*40;
prct.employer.l.p99=prctile(firms(:,8),99)*40;
st.firms.h=NaN;
st.firms.h=NaN;
ave.employer.h=mean(firms(:,7))*40;
ave.self.h=NaN;
ave.firms.h=mean(firms(:,7))*40;
ave.firms_median.h=median(firms(:,7))*40;
income_ratio = NaN;
wealth_income = sum(panel(:,3))./(sum(firms(:,14))+sum(workers(:,6).*grid_w(workers(:,4))));

%average age
aux = firms(firms(:,11)<1000,11);
ave_age = mean(aux);

%workers' income inequality
worker_inc = wage*grid_w(workers(:,4));
worker_disp.gini = ginicoeff(worker_inc);

wealth_income = sum(panel(:,3))./(sum(firms(:,14))+sum(workers(:,6).*grid_w(workers(:,4))));

calibration_targets = [share_e; 
    ave_age;
    prct.employer.l.p95;
    entry_survive(5);
ave.employer.l;
worker_disp.gini;
wealth_income];

%% Wealth inequality

aux= firms(firms(:,3)>amin,3);
wealth.entre.std=std(log(aux));
    

%Owner relative to worker wealth
top25_ent = prctile(firms(:,3),75);
top75_ent = prctile(firms(:,3),25);
wealth.entre.r7525=top25_ent/top75_ent;


%% compute further moments

     
%degree of finacial frictions
aux = firms(firms(:,11)<900,:);
aux_e = aux;
aux_e(:,15) = wage*aux_e(:,8)+(r+delta)*aux_e(:,9)+xi>=0.95*theta*aux_e(:,3);
aux_e = sortrows(aux_e,11);
share_e_con = mean(aux_e(:,15));


%Table 8
total_output = sum(firms(:,6));
total_labor = sum(firms(:,8));
total_wealth = sum(firms(:,3));