clear
close all
clc

twotheta =0; %set to 1 for experiment which doubles borrowing abilities
%% 

% The code is written for a more general CES production function than used in the paper: [lambda h^rho+(1-lambda)L^rho]^(1/rho) where we set lambda=0.5. 
% As a consequence, mean firm productivities are rescaled as described below.
% 40 weekly hours are normalized to 1 for labor and owner hours.

mue = 0.8900; %mean log firm productivity. Rescale:  mue+log(lambda^((1-alpha)*eta/elas));
sigma = 0.1420; %std log firm productivity 
rho = 0.987;      %autocorrelation of log productivity     
xi=0.0;          %fixed costs of labor (not present in the paper)                                 
eta = 0.88;      %returns of scale
if twotheta==0
    theta =0.244;     %financial friction  
else
    theta = 2*0.244;
end
nu.mean = -1.05; %average log disutility 
nu.rho = 0.47;   %autocorrelation of log leissure   
nu.std = 0.9;   %std of log disitulity 
kappaS=0.445; %productivity scale of self-employed. Rescale: kappaS^(lambdaS*eta)/(lambda^((1-alpha)*eta/elas))
lambdaS = 0.61; %returns of scale of self-employed
prob_w = 0.350; %possibility to choose being a worker
sigma_w = 0.29; %standard deviation of shock to labor income
beta = 0.975; %discount factor
lambda = 0.5; %
lambda2 = 1-lambda;
elas=0.5; %parameter of CES function


%worker productivity
mu_w = 0; %mean log prod
rho_w = 0.95; %autocorrelation of worker productivity
nw = 5; %number of grid points
sigma2.w = (sigma_w^2)/(1-rho_w^2); %ergodic variance of AR1
[grid_w,P_w] = Tauchen(rho_w,nw,sigma2.w,mu_w,'importance'); 
grid_w = exp(grid_w)';
prob_become_w = ones(nw,1)/nw;
prob_become_wcum = cumsum(prob_become_w);
P_wcum = cumsum(P_w,2);


phi = 2.0; %elasticity of labor supply
gamma = 1.5; %risk aversion (obsolete, we use log utility)
delta = 0.06; %depreciation rate
hmax=2.25; %upper bound on hours worked
nu.inov = nu.std;  


alpha = 0.33; %capital income share
alpha2=1-alpha;


if twotheta==0
    r = 0.00665; %guess for equilibrium interest rate
else
    r = 0.00613;
end

wage = (((alpha^alpha)*((1-alpha)^(1-alpha)))/(r+delta))^(1/(1-alpha)); %implied wage

%hours grid
nh = 10;
hgrid = linspace(0,hmax,nh)';

%productivity grid
nz = 21;
sigma2.z = (sigma^2)/(1-rho^2); %long-run variance
[Z,P] = Tauchen_asy(rho,nz,sigma2.z,mue);
z_min = min(Z);
z_max = max(Z);
log_Z=Z;
Z = exp(Z)';
Ptran = cumsum(P,2);


%grid of preferences
nnu = 6;
sigma2.nu = (nu.std^2)/(1-nu.rho^2);
[nu.grid,nu.P] = Tauchen(nu.rho,nnu,sigma2.nu,nu.mean,'importance'); 
nu.grid=nu.grid';
nu.tran = cumsum(nu.P,2);
nu_min = min(nu.grid);
nu_max = max(nu.grid);

nu.grid_log = nu.grid;
nu.min = min(nu.grid);
nu.max = max(nu.grid);
nu.grid = exp(nu.grid);


%compute largest possible firm (optimal unconstrained choice):
lgrid = linspace(0,500,400)';
Xgrid = (lambda*(hmax^elas)+lambda2*(lgrid.^elas)).^(1/elas);

aux1=alpha*eta/(r+delta);
aux3 = 1/(1-alpha*eta);
aux4 = alpha2*eta/(1-alpha*eta);
aux5 = elas/(1-elas);

Yaux = (Z(end)*(aux1^(alpha*eta))*Xgrid.^(alpha2*eta)).^aux3;
Kaux = Yaux*aux1;
PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
[~,index] = max(PIaux);
Y_max=Yaux(index);
K_max = Kaux(index);
L_max = lgrid(index);

if L_max==max(lgrid)
    xyz %increase upper bound on labor
end

%asset grid
amin = 0.01;
amax = max(6*wage,(K_max*(r+delta)+wage*L_max+xi)/theta);
na = 244;
agrid = [amin; wage/15; wage/10; wage/9; wage/8; wage/7; wage/6; wage/5; wage/4; wage/3; wage/2; wage; wage*1.5; wage*2; wage*2.5; wage*3; wage*3.5; wage*4; wage*5; wage*6; wage*7;];
aux = linspace(wage*7,amax/10,(na/2)-19)';
agrid = [agrid; aux(2:end)];
aux = linspace(amax/10,amax,ceil(na/2+1))';
agrid = [agrid; aux(2:end)];
na = na+1; %total number of grid points for state

%grid of asset choices (larger than agrid)
diffa=diff(agrid);
diffa2=diffa/9;
agridp=zeros(9*na-8,1);
for i =1:na-1
    agridp(1+9*(i-1):9*i,1) = agrid(i)+(0:8)'*diffa2(i);
end
agridp(end)=agrid(end);
nap = length(agridp);
%compute weights for interpolation of agridp on agrid
[~,xia] = histc(agridp,agrid); %find lower bounds on asset grid
xia(agridp<agrid(1)) = 1;
xia(agridp>=agrid(end)) = na-1;
sia = (agridp - agrid(xia))./diffa(xia);


lgrid = linspace(0,L_max,400)';

%minimum consumption
sub = 10^(-100);

%% solve for posible (4) static choices on grid points and hours choices


L = zeros(na,nz,nh,4); %labor choice
K = zeros(na,nz,nh,4); %capital choice
Yin = zeros(na,nz,nh,4); %implied output
Cin = zeros(na,nz,nh,4); %implied costs

%loop over states
for i = 1:na
    aux6 = theta*agrid(i)-xi;
    for j = 1:nz
        for i2 = 1:nh %loop of hours choice
            h = hgrid(i2);
            
            Xgrid = (lambda*(h^elas)+lambda2*(lgrid.^elas)).^(1/elas);
            %case 1: L>0 FC do not bind
            if aux6>0.0001
                Yaux = (Z(j)*(aux1^(alpha*eta))*Xgrid.^(alpha2*eta)).^aux3;
                Kaux = Yaux*aux1;
                upper = (aux6-wage*lgrid)/(r+delta);
                index = Kaux>upper;
                Yaux(index) = 0;
                PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
                [~,index] = max(PIaux);
                Yin(i,j,i2,1)=Yaux(index);
                K(i,j,i2,1)=Kaux(index);
                L(i,j,i2,1) = lgrid(index);
                Cin(i,j,i2,1)=(r+delta)*Kaux(index)+wage*lgrid(index);
            else
                Yin(i,j,i2,1)=-1000;
            end
            
            %case 2: L>0, FC bind
            if aux6>0.0001
                Kaux = (aux6-wage*lgrid)/(r+delta);
                Kaux(Kaux<0) = 0;
                Yaux = Z(j)*(Kaux.^(alpha*eta)).*(Xgrid.^(alpha2*eta));
                PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
                [~,index] = max(PIaux);
                Yin(i,j,i2,2)=Yaux(index);
                K(i,j,i2,2)=Kaux(index);
                L(i,j,i2,2) = lgrid(index);
                Cin(i,j,i2,2)=(r+delta)*Kaux(index)+wage*lgrid(index);
            else
                Yin(i,j,i2,2)=-1000;
            end
            
            if h==0
                Yin(i,j,i2,3)=-1000;
                Yin(i,j,i2,4)=-1000;
            else
                %case 3: lm=0,lb=0, FC no bind
                y=(Z(j)*(aux1^(alpha*eta))*((kappaS*h)^(lambdaS*eta)))^aux3;
                kk = aux1*y;
                upper = (theta*agrid(i))/(r+delta);
                if (kk/upper>1.005 && (kk-upper)>0.01)
                    y=0;
                end
                Cin(i,j,i2,3) = (r+delta)*kk;
                Yin(i,j,i2,3)=y;
                K(i,j,i2,3)=kk;
                L(i,j,i2,3) = 0;
                
                %case 6: lm=0,lb=0 FC bind
                y=Z(j)*(((aux6+xi)/(r+delta))^(alpha*eta))*((kappaS*h)^(lambdaS*eta));
                kk = (aux6+xi)/(r+delta);
                Cin(i,j,i2,4) = (r+delta)*kk;
                Yin(i,j,i2,4)=y;
                K(i,j,i2,4)=kk;
                L(i,j,i2,4) = 0;
            end
        end
    end
end

%% VFI

%consumption choices of workers
consumew = (1+r)*repmat(agrid,[1 nap nw])-repmat(agridp',[na 1 nw])+wage*repmat(reshape(grid_w,[1 1 nw]),[na nap 1]);
consumew = max(consumew,sub);
consumew = log(consumew); %utility

%disutility of working for workers and owners
hwutil = ((1.^(1+phi))./(1+phi));
heutil = ((hgrid.^(1+phi))./(1+phi));

%firm profits
PI=Yin-Cin;
PImax = zeros(na,nz);
for i =1:na
    for j = 1:nz
        PImax(i,j) = max(max(max(PI(i,j,:,:))));
    end
end

%static optimal labor choice
[PI_opt,index_l] = max(PI,[],4);


%guess labor and capital policy functions and value function
load('V.mat','V')
load('Vw.mat','Vw')

Vold_e = V;
Vold_w = Vw;

% Vold_e = zeros(na,nz,nnu,nw);
% Vold_w = zeros(na,nz,nnu,nw);


crit=1;
while crit>5*10^(-3)
    
    %employment decisions
    Echoice = Vold_e>Vold_w;
    
    EVE_e = (prob_w*max(Vold_e,Vold_w)+(1-prob_w)*Vold_e);
    EVE_w = max(Vold_e,Vold_w);
    
    %worker
    [Vw,index_w_h,index_w_a] = VFI_w_mex(EVE_w,consumew,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,hgrid,beta,gamma,phi,sub,r,wage,P,nu.P,int32(xia),sia,hwutil,P_w);
    
    %owners
    [V,index_a,index_h] = VFI_e4_mex(EVE_e,int32(na),int32(nap),int32(nz),int32(nnu),int32(nh),int32(nw),agrid,agridp,nu.grid,beta,gamma,sub,r,P,nu.P,P_w,int32(xia),sia,heutil,PI,PImax,PI_opt,hgrid,hmax);
    
    
    crit1 = max(max(max(max(abs(V-Vold_e)))));
    crit2 = max(max(max(max(abs(Vw-Vold_w)))));
    crit = max([crit1 crit2]);
    Vold_e = V;
    Vold_w = Vw;
    
end
save('V.mat','V')
save('Vw.mat','Vw')


%policies
lchoice = zeros(na,nz,nnu,nw); %labor choice
hchoice = zeros(na,nz,nnu,nw); %hours choice
kchoice = zeros(na,nz,nnu,nw); %capital choice
aprime_e = zeros(na,nz,nnu,nw); %asset choice owners
hchoice_w = zeros(na,nz,nnu,nw); %hours choice workers=1
aprime_w = zeros(na,nz,nnu,nw); %asset choice workers
for i = 1:na
    for l = 1:nnu
        for j = 1:nz
            for k =1:nw
                aprime_e(i,j,l,k) = agridp(index_a(i,j,l,k));
                hchoice(i,j,l,k) = hgrid(index_h(i,j,l,k));
                lchoice(i,j,l,k) = L(i,j,index_h(i,j,l,k),index_l(i,j,index_h(i,j,l,k)));
                kchoice(i,j,l,k) = K(i,j,index_h(i,j,l),index_l(i,j,index_h(i,j,l,k)));
                hchoice_w(i,j,l,k) = 1;
                aprime_w(i,j,l,k) = agridp(index_w_a(i,j,l,k));
            end
        end
    end
end

%output
Y = output_ces(alpha,lambda,eta,elas,repmat(reshape(Z,[1 nz 1]),[na 1 nnu nw]),kchoice,lchoice,hchoice);
for i=1:na
    for j =1:nz
        for k = 1:nnu
            for l = 1:nw
                if (lchoice(i,j,k,l))==0
                    Y(i,j,k,nw) = Z(j)*(kchoice(i,j,k,l).^(alpha*eta))*(kappaS*(hchoice(i,j,k,l)))^(lambdaS*eta);
                end
            end
        end
    end
end
Costs = (r+delta)*kchoice+wage*lchoice+(lchoice>0)*xi;

%profits and consumption
PII = Y-Costs;
CC_e = zeros(na,nz,nnu,nw); %consumption owners
CC_w = zeros(na,nz,nnu,nw); %consumption workers
for i = 1:na
    for l = 1:nnu
        for j = 1:nz
            for k = 1:nw
                CC_e(i,j,l,k) = (1+r)*agrid(i)-aprime_e(i,j,l,k)+PII(i,j,l,k); %consumption owners
                CC_w(i,j,l,k) = (1+r)*agrid(i)-aprime_w(i,j,l,k)+hchoice_w(i,j,l,k)*wage*grid_w(k); %consumption workers
            end
        end
    end
end



%% Simulation
H=10000; %number of individuals
T=500; %time periods
rand('seed',262524);
randn('seed',276624);

z_shock = sigma*randn(H,T); %productivity shock
nu_shock = nu.std*randn(H,T); %utility shock
job_shock = rand(H,T); %possibility to become worker
w_shock = rand(H,T); %worker productivity shock


%initialization
load('panel_ergo.mat','panel_ergo') %load last saved simulation
panel = zeros(H,12,100); %prod, nu, A, w, C, Y, h, l, K, type1, age, ID

panel(:,12,1) =1:H;
panel(:,1,1) =panel_ergo(:,1);
panel(:,2,1) =panel_ergo(:,2);
panel(:,3,1) =panel_ergo(:,3);
panel(:,4,1) =panel_ergo(:,4);
panel(:,10,1) =panel_ergo(:,10);
panel(panel_ergo(:,10)==2,11,1) =1;


for t1=1:T-1 
    
    %lower grid points for state
    [~,xii] = histc(panel(:,3,t1),agrid); %find lower bounds assets
    xii(panel(:,3,t1)<=agrid(1)) = 1;
    xii(panel(:,3,t1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1),log_Z); %find lower bounds assets
    yii(panel(:,1,t1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1)>=log_Z(end)) = nz-1;
    [~,zii] = histc(panel(:,2,t1),nu.grid_log); %find lower bounds assets
    zii(panel(:,2,t1)<=nu.grid_log(1)) = 1;
    zii(panel(:,2,t1)>=nu.grid_log(end)) = nnu-1;
    
    %productivity next period
    panel(:,1,t1+1) = min(z_max+0.08,max(z_min-0.08,rho*panel(:,1,t1)+(1-rho)*mue+z_shock(:,t1)));
    
    %leissure next period
    panel(:,2,t1+1) = min(nu_max+0.2,max(nu_min-0.2,nu.rho*panel(:,2,t1)+(1-nu.rho)*nu.mean+nu_shock(:,t1)));
    
    for i1 = 1:H
        %asset,labor,hours choice
        if panel(i1,10,t1) == 1 %worker
            panel(i1,7,t1) = 1;
            panel(i1,3,t1+1) = interp3_l(agrid,log_Z,nu.grid_log,aprime_w(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1));
            panel(i1,6,t1) = wage;
        else
            panel(i1,7,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,hchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,8,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,lchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,9,t1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,kchoice(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            panel(i1,3,t1+1) = max(0,interp3_l(agrid,log_Z,nu.grid_log,aprime_e(:,:,:,panel(i1,4,t1)),panel(i1,3,t1),panel(i1,1,t1),panel(i1,2,t1),xii(i1),yii(i1),zii(i1)));
            if panel(i1,8,t1)>0
                panel(i1,6,t1) = output_ces(alpha,lambda,eta,elas,exp(panel(i1,1,t1)),panel(i1,9,t1),panel(i1,8,t1),panel(i1,7,t1));
            else
                panel(i1,6,t1) = exp(panel(i1,1,t1))*((panel(i1,9,t1).^(alpha*eta)))*((kappaS*panel(i1,7,t1))^(lambdaS*eta));
            end
        end
    end
    
    %next period states
    [~,xii] = histc(panel(:,3,t1+1),agrid); %find lower bounds assets
    xii(panel(:,3,t1+1)<=agrid(1)) = 1;
    xii(panel(:,3,t1+1)>=agrid(end)) = na-1;
    [~,yii] = histc(panel(:,1,t1+1),log_Z); %find lower bounds prod
    yii(panel(:,1,t1+1)<=log_Z(1)) = 1;
    yii(panel(:,1,t1+1)>=log_Z(end)) = nz-1;
    [~,zii] = histc(panel(:,2,t1+1),nu.grid_log); %find lower bounds disutility
    zii(panel(:,2,t1+1)<=nu.grid_log(1)) = 1;
    zii(panel(:,2,t1+1)>=nu.grid_log(end)) = nnu-1;
    for i1 = 1:H
        %type transition
        panel(i1,4,t1+1) = sum(w_shock(i1,t1)>P_wcum(panel(i1,4,t1),:))+1;
        if panel(i1,10,t1) == 1 %worker
            echoice = interp3_l(agrid,log_Z,nu.grid_log,Echoice(:,:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),panel(i1,2,t1+1),xii(i1),yii(i1),zii(i1));
            if echoice<=0.5
                panel(i1,10,t1+1) = 1;
            else
                panel(i1,10,t1+1) = 2; %choose being an owner
                panel(i1,11,t1+1) = 1; 
            end
        else
            if job_shock(i1,t1)<prob_w %can become worker
                echoice = interp3_l(agrid,log_Z,nu.grid_log,Echoice(:,:,:,panel(i1,4,t1+1)),panel(i1,3,t1+1),panel(i1,1,t1+1),panel(i1,2,t1+1),xii(i1),yii(i1),zii(i1));
                if echoice>0.5
                    panel(i1,10,t1+1) = 2; %staz worker
                    panel(i1,11,t1+1) = panel(i1,11,t1)+1; %one year older
                else
                    panel(i1,10,t1+1) = 1;
                end
            else
                panel(i1,10,t1+1) = 2;
                panel(i1,11,t1+1) = panel(i1,11,t1)+1;
            end
        end
    end
end

panel(:,12,end) =1:H;
panel = panel(:,:,101:T); %delete first 100 observations
for t1 = 1:T-100
    prod(t1,1) = mean(panel(:,1,t1)); %average productivity
    leis(t1,1) = mean(panel(:,2,t1)); %average disutility
    share_e(t1,1) = mean(panel(:,10,t1)==2); %share of owners
    supply_a(t1,1) = sum(panel(:,3,t1)); %asset supplz
    demand_a(t1,1) = sum(panel(:,9,t1)); %asset demand by owners
    supply_w(t1,1) = sum(grid_w(panel(panel(:,10,t1)==1,4,t1))); %labor supply by workers
    demand_w(t1,1) = sum(panel(:,8,t1)); %labor demand by owners
end

%equilibrium
net_supply.w = mean(supply_w-demand_w)/H;
net_supply.a = mean(supply_a-demand_a)/H


ratio1 = net_supply.w/net_supply.a;
alpha/(1-alpha)*wage*ratio1-delta %equilibrium interest rate condition. Adjust "r" to make it equal


panel_ergo = panel(:,:,end);
save('panel_ergo.mat','panel_ergo')

%% Statistics

%transform to 2D matrix
panel2 = zeros(H*(T-100),12);
for h = 1:H
    transform = squeeze(panel(h,:,1:end));
    transform = transform';
    panel2(1+(h-1)*(T-100):h*(T-100),:) = transform;
end
panel = panel2;
clear panel2

%autocorrlation of hours 
clear aux
aux(:,1) = panel(:,7)*40;
aux(:,2)=panel(:,10)==2;
aux(:,3)=panel(:,12);
fcn = @(x){create_lag(x,1)};
aux(:,4) = accumarray_expand(aux(:,2),aux(:,3),fcn);%lagged employment status
aux(:,5) = accumarray_expand(aux(:,1),aux(:,3),fcn);%lagged hours
fcn = @(x){diff_l(x)};
aux(:,6) = accumarray_expand(aux(:,2),aux(:,3),fcn);%diff employment status
fcn = @(x){create_lead(x,1)};
aux(:,6) = accumarray_expand(aux(:,6),aux(:,3),fcn);
aux2=aux(aux(:,2)==1,:);
aux2=aux2(aux2(:,4)==1,:);
h_autocorr = corr(aux2(:,1),aux2(:,5)); %autocorrelation of hours

%survive for first 8 years
aux = panel(panel(:,10)==2,:);
aux = aux(aux(:,11)<1000,:); %drop firms that survive burn-in period
entry_survive = zeros(10,1);
for t1 = 1:10
    entry_survive(t1,1) = sum(aux(:,11)==t1);
end
entry_survive = entry_survive./entry_survive(1);

index = logical((panel(:,10)==2).*(panel(:,7)>0)); %idenify owners
share_e=mean(index); %share of owners
firms = panel(index==1,:);

%firm size category
firms(:,13) = 0; 
index = firms(:,8)==0;
firms(index,13) = 1;
index = (firms(:,8)>=0.5).*(firms(:,8)<4.5);
firms(logical(index),13) = 2;
index = (firms(:,8)>=4.5).*(firms(:,8)<9.5);
firms(logical(index),13) = 3;
index = (firms(:,8)>=9.5).*(firms(:,8)<19.5);
firms(logical(index),13) = 4;
index = (firms(:,8)>=19.5).*(firms(:,8)<49.5);
firms(logical(index),13) = 5;
index = firms(:,8)>=49.5;
firms(logical(index),13) = 6;

%profits
firms(:,14) = firms(:,6)-wage*firms(:,8)-(r+delta)*firms(:,9);

%identify employers, non-employers, and workers
index = firms(:,8)==0; %non-employers
ave.all.f0=mean(index); %share of non-employers
employers = firms(index==0,:);
self = firms(index==1,:);
workers = panel(panel(:,10)==1,:);



ave.employer.l=mean(employers(:,8)*40); %average employer size
prct.employer.l.p95=prctile(employers(:,8),95)*40; %95th percentile
st.firms.h=std(log(firms(:,7)*40)); %standard deviation of hours
ave.employer.h=mean(employers(:,7))*40; %average hours among employers
ave.self.h=mean(self(:,7))*40; %average hours of non-employers
wealth_income = sum(panel(:,3))./(sum(firms(:,14))+sum(workers(:,6).*grid_w(workers(:,4)))); %wealth to income ratio


%workers' income inequality
worker_inc = wage*grid_w(workers(:,4));
worker_disp.gini = ginicoeff(worker_inc);

%average firm age
aux = firms(firms(:,11)<1000,11);
ave_age = mean(aux);

%output dispersion
y_ratio7525 = prctile(employers(:,6),75)/prctile(employers(:,6),25);
y_ratio9050 = prctile(employers(:,6),90)/prctile(employers(:,6),50);
y_ratio9075 = prctile(employers(:,6),90)/prctile(employers(:,6),75);
output_ratio_mean = mean(employers(:,6))/mean(self(:,6)); %mean output of employers relative to non-employers
output_ratio_median = prctile(employers(:,6),50)/prctile(self(:,6),50); %median output of employers relative to non-employers

%income ratios owners/workers
income_ratio_mean = mean(firms(:,14))/mean(worker_inc);
income_ratio_median = median(firms(:,14))/median(worker_inc);

%hours over firm size and hours dispersion
size1_h = mean(firms(firms(:,13)==1,7))*40;
size2_h = mean(firms(firms(:,13)==2,7))*40;
size3_h = mean(firms(firms(:,13)==3,7))*40;
size4_h = mean(firms(firms(:,13)==4,7))*40;
size5_h = mean(firms(firms(:,13)==5,7))*40;
size6_h = mean(firms(firms(:,13)==6,7))*40;
h_ratio9010 = prctile(employers(:,7),90)/prctile(employers(:,7),10);
h_ratio7525 = prctile(employers(:,7),75)/prctile(employers(:,7),25);
h_ratio9075 = prctile(employers(:,7),90)/prctile(employers(:,7),75);
size_h5 = mean(firms(firms(:,13)>2,7))*40; %hours of those larger 5


%labor dispersion
l_ratio9075 = prctile(employers(:,8),90)/prctile(employers(:,8),75);
l_ratio9590 = prctile(employers(:,8),95)/prctile(employers(:,8),90);
l_ratio9050 = prctile(employers(:,8),90)/prctile(employers(:,8),50);
l_prct95 = prctile(employers(:,8),95)*40;


%h/l ratio over firm size
size1_hl = mean((firms(firms(:,13)==1,7))./(firms(firms(:,13)==1,8)));
size2_hl = mean((firms(firms(:,13)==2,7))./(firms(firms(:,13)==2,8)));
size3_hl = mean((firms(firms(:,13)==3,7))./(firms(firms(:,13)==3,8)));
size4_hl = mean((firms(firms(:,13)==4,7))./(firms(firms(:,13)==4,8)));
size5_hl = mean((firms(firms(:,13)==5,7))./(firms(firms(:,13)==5,8)));
size6_hl = mean((firms(firms(:,13)==6,7))./(firms(firms(:,13)==6,8)));

%labor/hours over age
size_firms_age = zeros(8,1);
size_employers_age = zeros(8,1);
hours_firms_age = zeros(8,1);
hours_employers_age = zeros(8,1);
for t1=1:5
    aux = firms(firms(:,11)==t1,:);
    size_firms_age(t1,1) = mean(aux(:,8));
    hours_firms_age(t1,1) = mean(aux(:,7));
    aux = employers(employers(:,11)==t1,:);
    size_employers_age(t1,1) = mean(aux(:,8));
    hours_employers_age(t1,1) = mean(aux(:,7));
end
index = logical((firms(:,11)>=6).*(firms(:,11)<=8));
size_firms_age(6,1) = mean((firms(index,8)));
hours_firms_age(6,1) = mean((firms(index,7)));
index = logical((firms(:,11)>=9).*(firms(:,11)<=17));
size_firms_age(7,1) = mean((firms(index,8)));
hours_firms_age(7,1) = mean((firms(index,7)));
index = logical((firms(:,11)>=18).*(firms(:,11)<=27));
size_firms_age(8,1) = mean((firms(index,8)));
hours_firms_age(8,1) = mean((firms(index,7)));
index = logical((employers(:,11)>=6).*(employers(:,11)<=8));
size_employers_age(6,1) = mean((employers(index,8)));
hours_employers_age(6,1) = mean(employers(index,7));
index = logical((employers(:,11)>=9).*(employers(:,11)<=17));
size_employers_age(7,1) = mean((employers(index,8)));
hours_employers_age(7,1) = mean((employers(index,7)));
index = logical((employers(:,11)>=18).*(employers(:,11)<=27));
size_employers_age(8,1) = mean((employers(index,8)));
hours_employers_age(8,1) = mean((employers(index,7)));

%share non-employers, productivity, and preferences over age
share_f0 = zeros(8,1);
age_z = zeros(8,1);
age_nu = zeros(8,1);
for t1=1:5
    aux = firms(firms(:,11)==t1,:);
    share_f0(t1,1) = mean((aux(:,8))==0);
    age_z(t1,1) = mean(exp(aux(:,1)));
    age_nu(t1,1) = mean(aux(:,2));
end
index = logical((firms(:,11)>=6).*(firms(:,11)<=8));
share_f0(6,1) = mean((firms(index,8))==0);
age_z(6,1) = mean(exp(firms(index,1)));
age_nu(6,1) = mean(firms(index,2));
index = logical((firms(:,11)>=9).*(firms(:,11)<=17));
share_f0(7,1) = mean((firms(index,8))==0);
age_z(7,1) = mean(exp(firms(index,1)));
age_nu(7,1) = mean(firms(index,2));
index = logical((firms(:,11)>=18).*(firms(:,11)<=27));
share_f0(8,1) = mean((firms(index,8))==0);
age_z(8,1) = mean(exp(firms(index,1)));
age_nu(8,1) = mean(firms(index,2));


%corr log profits and log assets
corr_pi_a(1,1) = corr(firms(:,3),firms(:,14));
aux = firms(firms(:,3)>amin,:);
aux = aux(aux(:,14)>0,:);
corr_pi_a(2,1) = corr(log(aux(:,14)),log(aux(:,3)));


%corr log profits and log hours by size
corr_h_y = zeros(6,1);
for i = 1:6
    aux = firms(firms(:,13)==i,:);
    aux = aux(aux(:,6)>0,:);
    aux = aux(logical((aux(:,7))>0),:);
    corr_h_y(i,1) = corr(log(aux(:,7)),log(aux(:,6)));
end


%degree of finacial frictions
aux = firms(firms(:,11)<900,:); %drop those surviving burn-in period
index = (aux(:,8))==0; %non-employers
aux_s = aux(index,:);
aux_s(:,15) = (r+delta)*aux_s(:,9)+xi>=0.95*theta*aux_s(:,3);
aux_s = sortrows(aux_s,11);
aux_e = aux(index==0,:);
aux_e(:,15) = wage*aux_e(:,8)+(r+delta)*aux_e(:,9)+xi>=0.95*theta*aux_e(:,3);
aux_e = sortrows(aux_e,11);
aux_all = [aux_s; aux_e];
pos1=(exp(aux_all(:,1)).*((alpha*eta/(r+delta))^(alpha*eta)).*((kappaS*aux_all(:,7)).^(lambdaS*eta))).^(1/(1-alpha*eta)); %output
pos1(:,2) = ((alpha*eta/(r+delta))*pos1*(r+delta))/theta; %required assets
pos1(:,1) = pos1(:,1)-(r+delta)*(alpha*eta/(r+delta))*pos1(:,1); %profits from self-employment
pos2 = zeros(length(aux_all),2);
for i1 = 1:length(aux_all)
    Xgrid = (lambda*(aux_all(i1,7)^elas)+lambda2*(lgrid.^elas)).^(1/elas);
    Yaux = (exp(aux_all(i1,1))*((alpha*eta/(r+delta))^(alpha*eta))*Xgrid.^(alpha2*eta)).^(1/(1-alpha*eta));
    Kaux = Yaux*(alpha*eta/(r+delta));
    PIaux = Yaux-wage*lgrid-(r+delta)*Kaux;
    [pos2(i1,1),index] = max(PIaux);
    pos2(i1,2) = (Kaux(index)*(r+delta)+wage*lgrid(index))/theta; %required assets
end
all = [pos1(:,1) pos2(:,1)];
[~,index] = max(all,[],2);
assets_opt = zeros(length(aux_all),1);
for i1 = 1:length(aux_all)
    if index(i1)==1
        assets_opt(i1) = pos1(i1,2);
    else
        assets_opt(i1) = pos2(i1,2);
    end
end
aux_all(:,16) = assets_opt./aux_all(:,3);
aux_all(:,17) = (assets_opt-aux_all(:,3))./(wage);
aux_all = sortrows(aux_all,11);
share_con = mean(aux_all(:,15)); %share of constrained owners


%calculate how firms became rich
%identify rich firms
index = prctile(firms(:,3),90);
aux =panel;
aux(:,15) = (aux(:,3)>=index).*(aux(:,10)==2); %in top 10 percentile of wealth
%create firm spells
aux(:,16) = aux(:,10)==2;
aux(2:end,16) = diff(aux(:,16));
aux(:,16)=aux(:,16)==1;
aux(:,16) = cumsum(aux(:,16));
aux(aux(:,10)==1,:) =[];
%keep job spells with high wealth observation
fcn = @(x){max(x)};
aux(:,15) = accumarray_expand(aux(:,15),aux(:,16),fcn);
aux = aux(aux(:,15)==1,:);
%drop if first observation (initialization) is max observation
aux(2:end,17) = diff(aux(:,16));
aux(1,17) =1;
aux(:,17) =aux(:,17)~=0;
aux(:,15) = accumarray_expand(aux(:,3),aux(:,16),fcn);
aux(:,17) = (aux(:,17)==1).*(aux(:,15)==aux(:,3));
aux(:,17) = accumarray_expand(aux(:,17),aux(:,16),fcn);
aux=aux(aux(:,17)==0,:);
%drop observations after max
aux(:,17) =aux(:,3)==aux(:,15);
fcn = @(x){cumsum(x)};
aux(:,17) = accumarray_expand(aux(:,17),aux(:,16),fcn);
aux(logical(aux(:,3)==aux(:,15)),17) = 0;
aux(aux(:,17)==1,:) =[];
fcn = @(x){mean(x)};
hours_rich = accumarray_expand_s(aux(:,7),aux(:,16),fcn);
hours_rich_5y = accumarray_expand_s(aux(aux(:,11)<6,7),aux(aux(:,11)<6,16),fcn);
hours_rich_10y = accumarray_expand_s(aux(aux(:,11)<11,7),aux(aux(:,11)<11,16),fcn);
fcn = @(x){max(x)};
hours_max_rich = accumarray_expand_s(aux(:,7),aux(:,16),fcn);
%mean productivity and disutility of work during first 8 years
aux2 = aux(aux(:,11)<9,:);
aux2 = sortrows(aux2,11);
fcn = @(x){mean(x)};
rich.prod_8y = accumarray_expand_s(aux2(:,1),aux2(:,11),fcn);
rich.nu_8y = accumarray_expand_s(aux2(:,2),aux2(:,11),fcn);
rich.h_8y = accumarray_expand_s(aux2(:,7),aux2(:,11),fcn)*40;
rich.l_8y = accumarray_expand_s(aux2(:,8),aux2(:,11),fcn)*40;
%employment growth
aux(:,17) = (aux(:,8)).*(aux(:,11)==1)*40; 
fcn = @(x){max(x)};
aux(:,17) = accumarray_expand(aux(:,17),aux(:,16),fcn);
aux(:,18) = (aux(:,8)).*(aux(:,11)==5)*40; 
fcn = @(x){max(x)};
aux(:,18) = accumarray_expand(aux(:,18),aux(:,16),fcn);
aux(:,19) = (aux(:,8)).*(aux(:,11)==10)*40; 
fcn = @(x){max(x)};
aux(:,19) = accumarray_expand(aux(:,19),aux(:,16),fcn);
aux = aux(aux(:,11)==1,:);
labor_growth_rich_5y = mean(aux(:,18)-aux(:,17));
labor_growth_rich_10y = mean(aux(:,19)-aux(:,17));



%identify poor firms
bad_firm = prctile(firms(:,3),10);
aux =firms;
aux(:,15) = 0;
%create firm spells
aux(2:end,16) = diff(aux(:,11));
aux(:,16)=aux(:,16)<=0;
aux(1,16)=1;
aux(:,16) = cumsum(aux(:,16));
%minimum wealth after year 7
aux(:,15) = (aux(:,3)).*(aux(:,11)>7);
aux(aux(:,15)==0,15) = 100000;
fcn = @(x){min(x)};
aux(:,15) = accumarray_expand(aux(:,15),aux(:,16),fcn);
aux(:,15) = aux(:,15)<bad_firm;
aux =aux(aux(:,15)==1,:);
aux = aux(aux(:,11)<9,:);
aux = sortrows(aux,11);
fcn = @(x){mean(x)};
poor.prod_8y = accumarray_expand_s(aux(:,1),aux(:,11),fcn);
poor.nu_8y = accumarray_expand_s(aux(:,2),aux(:,11),fcn);
poor.h_8y = accumarray_expand_s(aux(:,7),aux(:,11),fcn)*40;
poor.l_8y = accumarray_expand_s(aux(:,8),aux(:,11),fcn)*40;


%compare to all firms surviving at least 8 years
aux2 = firms(firms(:,11)<9,:);
%create firm spells
aux2(2:end,16) = diff(aux2(:,11));
aux2(:,16)=aux2(:,16)<=0;
aux2(1,16)=1;
aux2(:,16) = cumsum(aux2(:,16));
%keep surving for 8 years
fcn = @(x){sum(x)};
aux2(:,17) = 1;
aux2(:,17) = accumarray_expand(aux2(:,17),aux2(:,16),fcn);
aux2 = aux2(aux2(:,17)>7,:);
aux2 = sortrows(aux2,11);
fcn = @(x){mean(x)};
all_firms.prod_8y = accumarray_expand_s(aux2(:,1),aux2(:,11),fcn);
all_firms.nu_8y = accumarray_expand_s(aux2(:,2),aux2(:,11),fcn);
all_firms.h_8y = accumarray_expand_s(aux2(:,7),aux2(:,11),fcn)*40;
all_firms.l_8y = accumarray_expand_s(aux2(:,8),aux2(:,11),fcn)*40;


%dynamics conditional on year 1 hours
aux = firms;
aux(:,15) = (aux(:,11) == 1).*((aux(:,7))*40 <=20); %fewer than 20 hours in year 1
aux(:,16) = aux(:,11) == 1;
fcn = @(x){cumsum(x)};
aux(:,16) = accumarray_expand(aux(:,16),aux(:,12),fcn);
aux(:,12) = group([aux(:,12) aux(:,16)]);
fcn = @(x){cumsum(x)};
aux(:,15) = accumarray_expand(aux(:,15),aux(:,12),fcn);
aux(aux(:,15)==0,:) = [];
aux(aux(:,11)>8,:) = []; %older than age 8
fcn = @(x){length(x)};
aux(:,16) = accumarray_expand(aux(:,15),aux(:,12),fcn);
aux(aux(:,16)<8,:) = []; %drop those observed for fewer than 8 years
for t1 = 1:8
    aux2 = aux(aux(:,11)==t1,:);
    aux2 = aux2(aux2(:,6)>0,:);
    initlowh(t1,1) = mean(aux2(:,7))*40; 
    initlowh(t1,2) = log(mean(aux2(:,6)));
    initlowh(t1,3) = mean(aux2(:,8))*40;
end
aux = firms;
aux(:,15) = (aux(:,11) == 1).*((aux(:,7))*40 >=60); %more than 60 hours in year 1
aux(:,16) = aux(:,11) == 1;
fcn = @(x){cumsum(x)};
aux(:,16) = accumarray_expand(aux(:,16),aux(:,12),fcn);
aux(:,12) = group([aux(:,12) aux(:,16)]);
fcn = @(x){cumsum(x)};
aux(:,15) = accumarray_expand(aux(:,15),aux(:,12),fcn);
aux(aux(:,15)==0,:) = [];
aux(aux(:,11)>8,:) = []; %older than age 8
fcn = @(x){length(x)};
aux(:,16) = accumarray_expand(aux(:,15),aux(:,12),fcn);
aux(aux(:,16)<8,:) = [];
for t1 = 1:8
    aux2 = aux(aux(:,11)==t1,:);
    aux2 = aux2(aux2(:,6)>0,:);
    inithighh(t1,1) = mean(aux2(:,7))*40;
    inithighh(t1,2) = log(mean(aux2(:,6)));
    inithighh(t1,3) = mean(aux2(:,8))*40;
end

%% Wealth inequality

%society
aux= panel(panel(:,3)>amin,3);
wealth.soc.std=std(log(aux)); %standard deviation of log wealth
wealth.soc.r9075=prctile(panel(:,3),90)/prctile(panel(:,3),75);
wealth.soc.r5025=prctile(panel(:,3),50)/prctile(panel(:,3),25);


%Percentiles in society
top5_soc = prctile(panel(:,3),95);
top10_soc = prctile(panel(:,3),90);
top25_soc = prctile(panel(:,3),75);
top50_soc = prctile(panel(:,3),50);
top75_soc = prctile(panel(:,3),25);


%Owners in the wealth distribution
ave.firms.a = mean(firms(:,3));
entre_in_top5 = mean(firms(:,3)>=top5_soc);
entre_in_top10 = mean(firms(:,3)>=top10_soc);
entre_in_top25 = mean(firms(:,3)>=top25_soc);
entre_in_bootm50 = mean(firms(:,3)<=top50_soc);
entre_in_bootm25 = mean(firms(:,3)<=top75_soc);


%Owner relative to worker wealth
ave.worker.a = mean(workers(:,3));
firms_a_rel_wa = mean(firms(:,3))/ave.worker.a; %owner wealth relative to worker wealth
top5_ent = prctile(firms(:,3),95);
top10_ent = prctile(firms(:,3),90);
top25_ent = prctile(firms(:,3),75);
top50_ent = prctile(firms(:,3),50);
top75_ent = prctile(firms(:,3),25);
firms_top5_rel_wa = top5_ent/ave.worker.a; %top 5% relative to worker wealth
firms_top10_rel_wa = top10_ent/ave.worker.a;
firms_top25_rel_wa = top25_ent/ave.worker.a;
firms_top50_rel_wa = top50_ent/ave.worker.a;
firms_top75_rel_wa = top75_ent/ave.worker.a;
aux= firms(firms(:,3)>amin,3);
wealth.entre.std=std(log(aux));
wealth.entre.r9075=top10_ent/top25_ent; %wealth ratios of owners
wealth.entre.r9050=top10_ent/top50_ent;
wealth.entre.r7525=top25_ent/top75_ent;
wealth.entre.r7550=top25_ent/top50_ent;
wealth.entre.r5025=top50_ent/top75_ent;

   
%% Tables/Figures

%Table A1
calibration_targets = [share_e; 
    ave_age; 
    entry_survive(5); 
    prct.employer.l.p95; 
    ave.employer.l;
    ave.all.f0; 
    st.firms.h;
    h_autocorr; 
    ave.employer.h; 
    size_h5;
    ave.self.h;
    worker_disp.gini;
    wealth_income]; 


%Table 2
aux_t2 = [l_ratio9590; l_ratio9075; l_ratio9050; y_ratio9050; y_ratio9075; y_ratio7525; h_ratio9010; h_ratio9075; h_ratio7525];


%Figure 1
policies = [agrid(1:end)./ave.firms.a hchoice(1:end,18,4,3)*40 lchoice(1:end,18,4,3)*40];
csvwrite('policies.csv',policies) %1: assets, 2: hours, 3: labor

%Figure 2
aux1 = [size1_h; size2_h; size3_h; size4_h; size5_h; size6_h];
aux_f2 = [size1_hl; size2_hl; size3_hl; size4_hl; size5_hl; size6_hl];
aux_f2 = [aux1 aux_f2];
aux_f2 =[aux_f2 corr_h_y]; %1: hours, 2: hours/labor, 3: correlation hours and output
csvwrite('aux_f2.csv',aux_f2)

%Figure 3
aux_f3 = [size_employers_age*40 share_f0];
csvwrite('aux_f3.csv',aux_f3) %1: size, 2: share of non-employers

%Figure 4
aux_f4 = [initlowh(:,1) inithighh(:,1) initlowh(:,2) inithighh(:,2) initlowh(:,3) inithighh(:,3)];
csvwrite('aux_f4.csv',aux_f4) %1: low h hours, 2: high h hours, 3: low h output, 4: high h output, 5: low h labor, 6: high h labor


%Table 3
aux_t3 = [firms_a_rel_wa wealth.entre.std; 
    firms_top5_rel_wa wealth.entre.r9075;
    firms_top10_rel_wa wealth.entre.r9050;
    firms_top25_rel_wa wealth.entre.r7550;
    firms_top50_rel_wa wealth.entre.r7525;
    firms_top75_rel_wa wealth.entre.r5025];


%Table 4
aux_t4 = [entre_in_top5; entre_in_top10; entre_in_top25; entre_in_bootm50; entre_in_bootm25];


%Figure 5
wealth_perc = zeros(10,1);
prod_perc = zeros(10,1);
f5 = firms(:,[1 3 7]); %productivity, assets, hours
wealth_perc(1,1) = prctile(f5(:,2),10);
f5(f5(:,2)<=wealth_perc(1,1),4) = 1; %create asset and productivity percentiles
prod_perc(1,1) = prctile(f5(:,1),10);
f5(f5(:,1)<=prod_perc(1,1),5) = 1;
for i=20:10:100 
    wealth_perc(i/10,1) = prctile(f5(:,2),i);
    index = logical((f5(:,2)<=prctile(f5(:,2),i)).*(f5(:,2)>prctile(f5(:,2),i-10)));
    f5(index,4) = i/10;
    prod_perc(i/10,1) = prctile(f5(:,1),i);
    index = logical((f5(:,1)<=prctile(f5(:,1),i)).*(f5(:,1)>prctile(f5(:,1),i-10)));
    f5(index,5) = i/10;
end
%hours percentiles by assets
f5 = sortrows(f5,4);
fcn = @(x){prctile(x,25)};
aux_f5(:,1) = accumarray_expand_s(f5(:,3),f5(:,4),fcn)*40;
fcn = @(x){prctile(x,50)};
aux_f5(:,2) = accumarray_expand_s(f5(:,3),f5(:,4),fcn)*40;
fcn = @(x){prctile(x,75)};
aux_f5(:,3) = accumarray_expand_s(f5(:,3),f5(:,4),fcn)*40;
%hours percentiles by prod
f5 = sortrows(f5,5);
fcn = @(x){prctile(x,25)};
aux_f5(:,4) = accumarray_expand_s(f5(:,3),f5(:,5),fcn)*40;
fcn = @(x){prctile(x,50)};
aux_f5(:,5) = accumarray_expand_s(f5(:,3),f5(:,5),fcn)*40;
fcn = @(x){prctile(x,75)};
aux_f5(:,6) = accumarray_expand_s(f5(:,3),f5(:,5),fcn)*40;
csvwrite('aux_f5.csv',aux_f5) %1: 25th hours by a, 2: 50th hours by a, 3: 75th hours by a, 4: 25th hours by z, ....

%Figure 6
aux_f6_1 = [rich.prod_8y poor.prod_8y all_firms.prod_8y]; %1: rich owners productivity, 2: poor owners productivity, 3: all owners productivity
csvwrite('aux_f6_1.csv',aux_f6_1)
aux_f6_2 = [rich.nu_8y poor.nu_8y all_firms.nu_8y]; %1: rich owners preferences, 2: poor owners preferences, 3: all owners preferences
csvwrite('aux_f6_2.csv',aux_f6_2)
aux_f6_3 = [rich.h_8y poor.h_8y all_firms.h_8y]; %1: rich owners hours, 2: poor owners hours, 3: all owners hours
csvwrite('aux_f6_3.csv',aux_f6_3)
aux_f6_4 = [rich.l_8y poor.l_8y all_firms.l_8y]; %1: rich owners labor, 2: poor owners labor, 3: all owners labor
csvwrite('aux_f6_4.csv',aux_f6_4)


%Figure 7
f7_base = [round(length(firms)/10)*ones(10,1) wealth_perc]; %number of owners by asset percentile 
csvwrite('f7_base.csv',f7_base) %1: number of owners, 2: asset percentiles


%Figure 8
f8_base = [round(length(firms)/10)*ones(10,1) prod_perc]; %number of owners by prod percentile
csvwrite('f8_base.csv',f8_base) %1: number of owners, 2: productivity percentiles


%Table 8
total_output = sum(firms(:,6));
total_labor = sum(firms(:,8));
total_wealth = sum(firms(:,3));
